# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'TransitRouterAttachmentArgs',
    'TransitRouterAttachmentArgsDict',
    'TransitRouterAttachmentTagArgs',
    'TransitRouterAttachmentTagArgsDict',
    'TransitRouterRouteTableTagArgs',
    'TransitRouterRouteTableTagArgsDict',
    'TransitRouterTagArgs',
    'TransitRouterTagArgsDict',
]

MYPY = False

if not MYPY:
    class TransitRouterAttachmentArgsDict(TypedDict):
        auto_publish_route_enabled: NotRequired[pulumi.Input[builtins.bool]]
        """
        是否自动同步TR路由到网络实例路由表中。true：是。false：否。
        """
        business_status: NotRequired[pulumi.Input[builtins.str]]
        """
        网络实例连接的业务状态。取值如下：Normal：正常。FinancialLocked：已冻结。
        """
        creation_time: NotRequired[pulumi.Input[builtins.str]]
        """
        网络实例连接的创建时间。
        """
        deleted_time: NotRequired[pulumi.Input[builtins.str]]
        """
        网络实例连接的删除时间。
        """
        description: NotRequired[pulumi.Input[builtins.str]]
        """
        网络实例连接的描述信息。
        """
        ipv6_enabled: NotRequired[pulumi.Input[builtins.bool]]
        """
        是否开启IPv6功能。true：是。false：否。
        """
        overdue_time: NotRequired[pulumi.Input[builtins.str]]
        """
        网络实例连接的欠费关停时间。
        """
        resource_id: NotRequired[pulumi.Input[builtins.str]]
        """
        网络实例的ID。
        """
        resource_type: NotRequired[pulumi.Input[builtins.str]]
        """
        网络实例连接关联的网络实例类型。VPC：私有网络。VPN：VPN连接。DirectConnectGateway：专线网关。TransitRouter：中转路由器。
        """
        status: NotRequired[pulumi.Input[builtins.str]]
        """
        网络实例连接的状态。Creating: 创建中。Deleting: 删除中。Pending：配置中。Available：可用。
        """
        tags: NotRequired[pulumi.Input[Sequence[pulumi.Input['TransitRouterAttachmentTagArgsDict']]]]
        transit_router_attachment_id: NotRequired[pulumi.Input[builtins.str]]
        """
        网络实例连接的ID。
        """
        transit_router_attachment_name: NotRequired[pulumi.Input[builtins.str]]
        """
        网络实例连接的名称。
        """
        transit_router_forward_policy_table_id: NotRequired[pulumi.Input[builtins.str]]
        """
        跨地域连接关联的转发策略的ID。
        """
        transit_router_id: NotRequired[pulumi.Input[builtins.str]]
        """
        中转路由器实例的ID。
        """
        transit_router_route_table_id: NotRequired[pulumi.Input[builtins.str]]
        """
        网络实例连接关联转发的路由表ID。
        """
        transit_router_traffic_qos_marking_policy_id: NotRequired[pulumi.Input[builtins.str]]
        """
        跨地域连接关联的流标记策略的ID。
        """
        transit_router_traffic_qos_queue_policy_id: NotRequired[pulumi.Input[builtins.str]]
        """
        跨地域连接关联的流队列策略的ID。
        """
        update_time: NotRequired[pulumi.Input[builtins.str]]
        """
        网络实例连接的最近操作时间。
        """
elif False:
    TransitRouterAttachmentArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class TransitRouterAttachmentArgs:
    def __init__(__self__, *,
                 auto_publish_route_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 business_status: Optional[pulumi.Input[builtins.str]] = None,
                 creation_time: Optional[pulumi.Input[builtins.str]] = None,
                 deleted_time: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 ipv6_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 overdue_time: Optional[pulumi.Input[builtins.str]] = None,
                 resource_id: Optional[pulumi.Input[builtins.str]] = None,
                 resource_type: Optional[pulumi.Input[builtins.str]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['TransitRouterAttachmentTagArgs']]]] = None,
                 transit_router_attachment_id: Optional[pulumi.Input[builtins.str]] = None,
                 transit_router_attachment_name: Optional[pulumi.Input[builtins.str]] = None,
                 transit_router_forward_policy_table_id: Optional[pulumi.Input[builtins.str]] = None,
                 transit_router_id: Optional[pulumi.Input[builtins.str]] = None,
                 transit_router_route_table_id: Optional[pulumi.Input[builtins.str]] = None,
                 transit_router_traffic_qos_marking_policy_id: Optional[pulumi.Input[builtins.str]] = None,
                 transit_router_traffic_qos_queue_policy_id: Optional[pulumi.Input[builtins.str]] = None,
                 update_time: Optional[pulumi.Input[builtins.str]] = None):
        """
        :param pulumi.Input[builtins.bool] auto_publish_route_enabled: 是否自动同步TR路由到网络实例路由表中。true：是。false：否。
        :param pulumi.Input[builtins.str] business_status: 网络实例连接的业务状态。取值如下：Normal：正常。FinancialLocked：已冻结。
        :param pulumi.Input[builtins.str] creation_time: 网络实例连接的创建时间。
        :param pulumi.Input[builtins.str] deleted_time: 网络实例连接的删除时间。
        :param pulumi.Input[builtins.str] description: 网络实例连接的描述信息。
        :param pulumi.Input[builtins.bool] ipv6_enabled: 是否开启IPv6功能。true：是。false：否。
        :param pulumi.Input[builtins.str] overdue_time: 网络实例连接的欠费关停时间。
        :param pulumi.Input[builtins.str] resource_id: 网络实例的ID。
        :param pulumi.Input[builtins.str] resource_type: 网络实例连接关联的网络实例类型。VPC：私有网络。VPN：VPN连接。DirectConnectGateway：专线网关。TransitRouter：中转路由器。
        :param pulumi.Input[builtins.str] status: 网络实例连接的状态。Creating: 创建中。Deleting: 删除中。Pending：配置中。Available：可用。
        :param pulumi.Input[builtins.str] transit_router_attachment_id: 网络实例连接的ID。
        :param pulumi.Input[builtins.str] transit_router_attachment_name: 网络实例连接的名称。
        :param pulumi.Input[builtins.str] transit_router_forward_policy_table_id: 跨地域连接关联的转发策略的ID。
        :param pulumi.Input[builtins.str] transit_router_id: 中转路由器实例的ID。
        :param pulumi.Input[builtins.str] transit_router_route_table_id: 网络实例连接关联转发的路由表ID。
        :param pulumi.Input[builtins.str] transit_router_traffic_qos_marking_policy_id: 跨地域连接关联的流标记策略的ID。
        :param pulumi.Input[builtins.str] transit_router_traffic_qos_queue_policy_id: 跨地域连接关联的流队列策略的ID。
        :param pulumi.Input[builtins.str] update_time: 网络实例连接的最近操作时间。
        """
        if auto_publish_route_enabled is not None:
            pulumi.set(__self__, "auto_publish_route_enabled", auto_publish_route_enabled)
        if business_status is not None:
            pulumi.set(__self__, "business_status", business_status)
        if creation_time is not None:
            pulumi.set(__self__, "creation_time", creation_time)
        if deleted_time is not None:
            pulumi.set(__self__, "deleted_time", deleted_time)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if ipv6_enabled is not None:
            pulumi.set(__self__, "ipv6_enabled", ipv6_enabled)
        if overdue_time is not None:
            pulumi.set(__self__, "overdue_time", overdue_time)
        if resource_id is not None:
            pulumi.set(__self__, "resource_id", resource_id)
        if resource_type is not None:
            pulumi.set(__self__, "resource_type", resource_type)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if transit_router_attachment_id is not None:
            pulumi.set(__self__, "transit_router_attachment_id", transit_router_attachment_id)
        if transit_router_attachment_name is not None:
            pulumi.set(__self__, "transit_router_attachment_name", transit_router_attachment_name)
        if transit_router_forward_policy_table_id is not None:
            pulumi.set(__self__, "transit_router_forward_policy_table_id", transit_router_forward_policy_table_id)
        if transit_router_id is not None:
            pulumi.set(__self__, "transit_router_id", transit_router_id)
        if transit_router_route_table_id is not None:
            pulumi.set(__self__, "transit_router_route_table_id", transit_router_route_table_id)
        if transit_router_traffic_qos_marking_policy_id is not None:
            pulumi.set(__self__, "transit_router_traffic_qos_marking_policy_id", transit_router_traffic_qos_marking_policy_id)
        if transit_router_traffic_qos_queue_policy_id is not None:
            pulumi.set(__self__, "transit_router_traffic_qos_queue_policy_id", transit_router_traffic_qos_queue_policy_id)
        if update_time is not None:
            pulumi.set(__self__, "update_time", update_time)

    @property
    @pulumi.getter(name="autoPublishRouteEnabled")
    def auto_publish_route_enabled(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        是否自动同步TR路由到网络实例路由表中。true：是。false：否。
        """
        return pulumi.get(self, "auto_publish_route_enabled")

    @auto_publish_route_enabled.setter
    def auto_publish_route_enabled(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "auto_publish_route_enabled", value)

    @property
    @pulumi.getter(name="businessStatus")
    def business_status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        网络实例连接的业务状态。取值如下：Normal：正常。FinancialLocked：已冻结。
        """
        return pulumi.get(self, "business_status")

    @business_status.setter
    def business_status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "business_status", value)

    @property
    @pulumi.getter(name="creationTime")
    def creation_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        网络实例连接的创建时间。
        """
        return pulumi.get(self, "creation_time")

    @creation_time.setter
    def creation_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "creation_time", value)

    @property
    @pulumi.getter(name="deletedTime")
    def deleted_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        网络实例连接的删除时间。
        """
        return pulumi.get(self, "deleted_time")

    @deleted_time.setter
    def deleted_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "deleted_time", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        网络实例连接的描述信息。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="ipv6Enabled")
    def ipv6_enabled(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        是否开启IPv6功能。true：是。false：否。
        """
        return pulumi.get(self, "ipv6_enabled")

    @ipv6_enabled.setter
    def ipv6_enabled(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "ipv6_enabled", value)

    @property
    @pulumi.getter(name="overdueTime")
    def overdue_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        网络实例连接的欠费关停时间。
        """
        return pulumi.get(self, "overdue_time")

    @overdue_time.setter
    def overdue_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "overdue_time", value)

    @property
    @pulumi.getter(name="resourceId")
    def resource_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        网络实例的ID。
        """
        return pulumi.get(self, "resource_id")

    @resource_id.setter
    def resource_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "resource_id", value)

    @property
    @pulumi.getter(name="resourceType")
    def resource_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        网络实例连接关联的网络实例类型。VPC：私有网络。VPN：VPN连接。DirectConnectGateway：专线网关。TransitRouter：中转路由器。
        """
        return pulumi.get(self, "resource_type")

    @resource_type.setter
    def resource_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "resource_type", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        网络实例连接的状态。Creating: 创建中。Deleting: 删除中。Pending：配置中。Available：可用。
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['TransitRouterAttachmentTagArgs']]]]:
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['TransitRouterAttachmentTagArgs']]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter(name="transitRouterAttachmentId")
    def transit_router_attachment_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        网络实例连接的ID。
        """
        return pulumi.get(self, "transit_router_attachment_id")

    @transit_router_attachment_id.setter
    def transit_router_attachment_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "transit_router_attachment_id", value)

    @property
    @pulumi.getter(name="transitRouterAttachmentName")
    def transit_router_attachment_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        网络实例连接的名称。
        """
        return pulumi.get(self, "transit_router_attachment_name")

    @transit_router_attachment_name.setter
    def transit_router_attachment_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "transit_router_attachment_name", value)

    @property
    @pulumi.getter(name="transitRouterForwardPolicyTableId")
    def transit_router_forward_policy_table_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        跨地域连接关联的转发策略的ID。
        """
        return pulumi.get(self, "transit_router_forward_policy_table_id")

    @transit_router_forward_policy_table_id.setter
    def transit_router_forward_policy_table_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "transit_router_forward_policy_table_id", value)

    @property
    @pulumi.getter(name="transitRouterId")
    def transit_router_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        中转路由器实例的ID。
        """
        return pulumi.get(self, "transit_router_id")

    @transit_router_id.setter
    def transit_router_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "transit_router_id", value)

    @property
    @pulumi.getter(name="transitRouterRouteTableId")
    def transit_router_route_table_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        网络实例连接关联转发的路由表ID。
        """
        return pulumi.get(self, "transit_router_route_table_id")

    @transit_router_route_table_id.setter
    def transit_router_route_table_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "transit_router_route_table_id", value)

    @property
    @pulumi.getter(name="transitRouterTrafficQosMarkingPolicyId")
    def transit_router_traffic_qos_marking_policy_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        跨地域连接关联的流标记策略的ID。
        """
        return pulumi.get(self, "transit_router_traffic_qos_marking_policy_id")

    @transit_router_traffic_qos_marking_policy_id.setter
    def transit_router_traffic_qos_marking_policy_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "transit_router_traffic_qos_marking_policy_id", value)

    @property
    @pulumi.getter(name="transitRouterTrafficQosQueuePolicyId")
    def transit_router_traffic_qos_queue_policy_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        跨地域连接关联的流队列策略的ID。
        """
        return pulumi.get(self, "transit_router_traffic_qos_queue_policy_id")

    @transit_router_traffic_qos_queue_policy_id.setter
    def transit_router_traffic_qos_queue_policy_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "transit_router_traffic_qos_queue_policy_id", value)

    @property
    @pulumi.getter(name="updateTime")
    def update_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        网络实例连接的最近操作时间。
        """
        return pulumi.get(self, "update_time")

    @update_time.setter
    def update_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "update_time", value)


if not MYPY:
    class TransitRouterAttachmentTagArgsDict(TypedDict):
        key: NotRequired[pulumi.Input[builtins.str]]
        """
        标签键。
        """
        value: NotRequired[pulumi.Input[builtins.str]]
        """
        标签值。
        """
elif False:
    TransitRouterAttachmentTagArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class TransitRouterAttachmentTagArgs:
    def __init__(__self__, *,
                 key: Optional[pulumi.Input[builtins.str]] = None,
                 value: Optional[pulumi.Input[builtins.str]] = None):
        """
        :param pulumi.Input[builtins.str] key: 标签键。
        :param pulumi.Input[builtins.str] value: 标签值。
        """
        if key is not None:
            pulumi.set(__self__, "key", key)
        if value is not None:
            pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        标签键。
        """
        return pulumi.get(self, "key")

    @key.setter
    def key(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "key", value)

    @property
    @pulumi.getter
    def value(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        标签值。
        """
        return pulumi.get(self, "value")

    @value.setter
    def value(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "value", value)


if not MYPY:
    class TransitRouterRouteTableTagArgsDict(TypedDict):
        key: NotRequired[pulumi.Input[builtins.str]]
        """
        标签键
        """
        value: NotRequired[pulumi.Input[builtins.str]]
        """
        标签值
        """
elif False:
    TransitRouterRouteTableTagArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class TransitRouterRouteTableTagArgs:
    def __init__(__self__, *,
                 key: Optional[pulumi.Input[builtins.str]] = None,
                 value: Optional[pulumi.Input[builtins.str]] = None):
        """
        :param pulumi.Input[builtins.str] key: 标签键
        :param pulumi.Input[builtins.str] value: 标签值
        """
        if key is not None:
            pulumi.set(__self__, "key", key)
        if value is not None:
            pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        标签键
        """
        return pulumi.get(self, "key")

    @key.setter
    def key(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "key", value)

    @property
    @pulumi.getter
    def value(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        标签值
        """
        return pulumi.get(self, "value")

    @value.setter
    def value(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "value", value)


if not MYPY:
    class TransitRouterTagArgsDict(TypedDict):
        key: NotRequired[pulumi.Input[builtins.str]]
        """
        标签键。
        """
        value: NotRequired[pulumi.Input[builtins.str]]
        """
        标签值。
        """
elif False:
    TransitRouterTagArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class TransitRouterTagArgs:
    def __init__(__self__, *,
                 key: Optional[pulumi.Input[builtins.str]] = None,
                 value: Optional[pulumi.Input[builtins.str]] = None):
        """
        :param pulumi.Input[builtins.str] key: 标签键。
        :param pulumi.Input[builtins.str] value: 标签值。
        """
        if key is not None:
            pulumi.set(__self__, "key", key)
        if value is not None:
            pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        标签键。
        """
        return pulumi.get(self, "key")

    @key.setter
    def key(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "key", value)

    @property
    @pulumi.getter
    def value(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        标签值。
        """
        return pulumi.get(self, "value")

    @value.setter
    def value(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "value", value)





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetNlbServerGroupResult',
    'AwaitableGetNlbServerGroupResult',
    'get_nlb_server_group',
    'get_nlb_server_group_output',
]

@pulumi.output_type
class GetNlbServerGroupResult:
    """
    A collection of values returned by getNlbServerGroup.
    """
    def __init__(__self__, account_id=None, any_port_enabled=None, bypass_security_group_enabled=None, connection_drain_enabled=None, connection_drain_timeout=None, created_time=None, description=None, health_check=None, id=None, ip_address_version=None, preserve_client_ip_enabled=None, project_name=None, protocol=None, proxy_protocol_type=None, related_load_balancer_ids=None, scheduler=None, server_count=None, server_group_id=None, server_group_name=None, servers=None, session_persistence_enabled=None, session_persistence_timeout=None, status=None, tags=None, timestamp_remove_enabled=None, type=None, updated_time=None, vpc_id=None):
        if account_id and not isinstance(account_id, str):
            raise TypeError("Expected argument 'account_id' to be a str")
        pulumi.set(__self__, "account_id", account_id)
        if any_port_enabled and not isinstance(any_port_enabled, bool):
            raise TypeError("Expected argument 'any_port_enabled' to be a bool")
        pulumi.set(__self__, "any_port_enabled", any_port_enabled)
        if bypass_security_group_enabled and not isinstance(bypass_security_group_enabled, bool):
            raise TypeError("Expected argument 'bypass_security_group_enabled' to be a bool")
        pulumi.set(__self__, "bypass_security_group_enabled", bypass_security_group_enabled)
        if connection_drain_enabled and not isinstance(connection_drain_enabled, bool):
            raise TypeError("Expected argument 'connection_drain_enabled' to be a bool")
        pulumi.set(__self__, "connection_drain_enabled", connection_drain_enabled)
        if connection_drain_timeout and not isinstance(connection_drain_timeout, int):
            raise TypeError("Expected argument 'connection_drain_timeout' to be a int")
        pulumi.set(__self__, "connection_drain_timeout", connection_drain_timeout)
        if created_time and not isinstance(created_time, str):
            raise TypeError("Expected argument 'created_time' to be a str")
        pulumi.set(__self__, "created_time", created_time)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if health_check and not isinstance(health_check, dict):
            raise TypeError("Expected argument 'health_check' to be a dict")
        pulumi.set(__self__, "health_check", health_check)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ip_address_version and not isinstance(ip_address_version, str):
            raise TypeError("Expected argument 'ip_address_version' to be a str")
        pulumi.set(__self__, "ip_address_version", ip_address_version)
        if preserve_client_ip_enabled and not isinstance(preserve_client_ip_enabled, bool):
            raise TypeError("Expected argument 'preserve_client_ip_enabled' to be a bool")
        pulumi.set(__self__, "preserve_client_ip_enabled", preserve_client_ip_enabled)
        if project_name and not isinstance(project_name, str):
            raise TypeError("Expected argument 'project_name' to be a str")
        pulumi.set(__self__, "project_name", project_name)
        if protocol and not isinstance(protocol, str):
            raise TypeError("Expected argument 'protocol' to be a str")
        pulumi.set(__self__, "protocol", protocol)
        if proxy_protocol_type and not isinstance(proxy_protocol_type, str):
            raise TypeError("Expected argument 'proxy_protocol_type' to be a str")
        pulumi.set(__self__, "proxy_protocol_type", proxy_protocol_type)
        if related_load_balancer_ids and not isinstance(related_load_balancer_ids, list):
            raise TypeError("Expected argument 'related_load_balancer_ids' to be a list")
        pulumi.set(__self__, "related_load_balancer_ids", related_load_balancer_ids)
        if scheduler and not isinstance(scheduler, str):
            raise TypeError("Expected argument 'scheduler' to be a str")
        pulumi.set(__self__, "scheduler", scheduler)
        if server_count and not isinstance(server_count, int):
            raise TypeError("Expected argument 'server_count' to be a int")
        pulumi.set(__self__, "server_count", server_count)
        if server_group_id and not isinstance(server_group_id, str):
            raise TypeError("Expected argument 'server_group_id' to be a str")
        pulumi.set(__self__, "server_group_id", server_group_id)
        if server_group_name and not isinstance(server_group_name, str):
            raise TypeError("Expected argument 'server_group_name' to be a str")
        pulumi.set(__self__, "server_group_name", server_group_name)
        if servers and not isinstance(servers, list):
            raise TypeError("Expected argument 'servers' to be a list")
        pulumi.set(__self__, "servers", servers)
        if session_persistence_enabled and not isinstance(session_persistence_enabled, bool):
            raise TypeError("Expected argument 'session_persistence_enabled' to be a bool")
        pulumi.set(__self__, "session_persistence_enabled", session_persistence_enabled)
        if session_persistence_timeout and not isinstance(session_persistence_timeout, int):
            raise TypeError("Expected argument 'session_persistence_timeout' to be a int")
        pulumi.set(__self__, "session_persistence_timeout", session_persistence_timeout)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if tags and not isinstance(tags, list):
            raise TypeError("Expected argument 'tags' to be a list")
        pulumi.set(__self__, "tags", tags)
        if timestamp_remove_enabled and not isinstance(timestamp_remove_enabled, bool):
            raise TypeError("Expected argument 'timestamp_remove_enabled' to be a bool")
        pulumi.set(__self__, "timestamp_remove_enabled", timestamp_remove_enabled)
        if type and not isinstance(type, str):
            raise TypeError("Expected argument 'type' to be a str")
        pulumi.set(__self__, "type", type)
        if updated_time and not isinstance(updated_time, str):
            raise TypeError("Expected argument 'updated_time' to be a str")
        pulumi.set(__self__, "updated_time", updated_time)
        if vpc_id and not isinstance(vpc_id, str):
            raise TypeError("Expected argument 'vpc_id' to be a str")
        pulumi.set(__self__, "vpc_id", vpc_id)

    @property
    @pulumi.getter(name="accountId")
    def account_id(self) -> builtins.str:
        """
        账号ID。
        """
        return pulumi.get(self, "account_id")

    @property
    @pulumi.getter(name="anyPortEnabled")
    def any_port_enabled(self) -> builtins.bool:
        """
        是否开启全端口转发。
        """
        return pulumi.get(self, "any_port_enabled")

    @property
    @pulumi.getter(name="bypassSecurityGroupEnabled")
    def bypass_security_group_enabled(self) -> builtins.bool:
        """
        是否开启放通后端安全组功能。仅参数Type为“instance”时，可以配置此参数。
        """
        return pulumi.get(self, "bypass_security_group_enabled")

    @property
    @pulumi.getter(name="connectionDrainEnabled")
    def connection_drain_enabled(self) -> builtins.bool:
        """
        是否开启连接优雅中断。
        """
        return pulumi.get(self, "connection_drain_enabled")

    @property
    @pulumi.getter(name="connectionDrainTimeout")
    def connection_drain_timeout(self) -> builtins.int:
        """
        连接优雅中断超时时间，取值范围为0～900秒。参数ConnectionDrainEnabled为“true”时，该参数为必填。
        """
        return pulumi.get(self, "connection_drain_timeout")

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> builtins.str:
        """
        后端服务器组的创建时间。
        """
        return pulumi.get(self, "created_time")

    @property
    @pulumi.getter
    def description(self) -> builtins.str:
        """
        后端服务器组的描述,服务器组的描述。必须以字母、数字或中文开头，可包含以下特殊字符：英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、中划线（-）、中文逗号（，）、中文句号（。）长度限制为0 ～ 255个字符。该参数不传入，则默认为空字符串。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="healthCheck")
    def health_check(self) -> 'outputs.GetNlbServerGroupHealthCheckResult':
        """
        健康检查相关参数。
        """
        return pulumi.get(self, "health_check")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        Uniquely identifies the resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="ipAddressVersion")
    def ip_address_version(self) -> builtins.str:
        """
        服务器组的IP地址类型。取值如下：ipv4（默认值）：表示该服务器组仅支持添加IPv4类型的后端服务器。ipv6：表示该服务器组仅支持添加IPv6类型的后端服务器。
        """
        return pulumi.get(self, "ip_address_version")

    @property
    @pulumi.getter(name="preserveClientIpEnabled")
    def preserve_client_ip_enabled(self) -> builtins.bool:
        """
        是否开启源地址保持。
        """
        return pulumi.get(self, "preserve_client_ip_enabled")

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> builtins.str:
        """
        项目名称。
        """
        return pulumi.get(self, "project_name")

    @property
    @pulumi.getter
    def protocol(self) -> builtins.str:
        """
        NLB转发流量到后端服务器时使用的通信协议。取值如下：TCP。UDP。
        """
        return pulumi.get(self, "protocol")

    @property
    @pulumi.getter(name="proxyProtocolType")
    def proxy_protocol_type(self) -> builtins.str:
        """
        是否开启Proxy-Protocol协议。取值如下：off（默认值）：关闭。standard：开启。NLB将通过Proxy-Protocol协议携带客户端源IP地址转发至后端服务器，还需要在后端服务器上配置Proxy-Protocol。
        """
        return pulumi.get(self, "proxy_protocol_type")

    @property
    @pulumi.getter(name="relatedLoadBalancerIds")
    def related_load_balancer_ids(self) -> Sequence[builtins.str]:
        """
        服务器组关联的NLB实例。
        """
        return pulumi.get(self, "related_load_balancer_ids")

    @property
    @pulumi.getter
    def scheduler(self) -> builtins.str:
        """
        NLB转发流量时遵循的规则。取值如下：wrr（默认值）：加权轮询，权重值越高的后端服务器，被轮询到的次数（概率）越高。wlc：加权最小连接数，在最少连接数的基础上，根据后端服务器的不同处理能力，给每个服务器分配不同的权重，使其能够接受相应权值数的服务请求。sh：源地址哈希，基于源IP地址的一致性哈希，相同的源地址会调度到相同的后端服务器。
        """
        return pulumi.get(self, "scheduler")

    @property
    @pulumi.getter(name="serverCount")
    def server_count(self) -> builtins.int:
        """
        服务器组中后端服务器的数量。
        """
        return pulumi.get(self, "server_count")

    @property
    @pulumi.getter(name="serverGroupId")
    def server_group_id(self) -> builtins.str:
        """
        服务器组ID。
        """
        return pulumi.get(self, "server_group_id")

    @property
    @pulumi.getter(name="serverGroupName")
    def server_group_name(self) -> builtins.str:
        """
        服务器组名称, 必须以字母、数字或中文开头，可包含以下特殊字符：点号（.）、下划线（_）和中划线（-）。限制为1 ～ 128个字符。该参数不传入，则默认为服务器组ID。
        """
        return pulumi.get(self, "server_group_name")

    @property
    @pulumi.getter
    def servers(self) -> Sequence['outputs.GetNlbServerGroupServerResult']:
        """
        服务器组中待添加后端服务器的信息。
        """
        return pulumi.get(self, "servers")

    @property
    @pulumi.getter(name="sessionPersistenceEnabled")
    def session_persistence_enabled(self) -> builtins.bool:
        """
        是否开启会话保持。
        """
        return pulumi.get(self, "session_persistence_enabled")

    @property
    @pulumi.getter(name="sessionPersistenceTimeout")
    def session_persistence_timeout(self) -> builtins.int:
        """
        会话保持的超时时间，取值范围为1～3600秒，默认1000秒。
        """
        return pulumi.get(self, "session_persistence_timeout")

    @property
    @pulumi.getter
    def status(self) -> builtins.str:
        """
        服务器组的状态。
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def tags(self) -> Sequence['outputs.GetNlbServerGroupTagResult']:
        """
        标签。
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="timestampRemoveEnabled")
    def timestamp_remove_enabled(self) -> builtins.bool:
        """
        是否开启清除TCP/HTTP/HTTPS报文的timestamp（即时间戳）的功能。
        """
        return pulumi.get(self, "timestamp_remove_enabled")

    @property
    @pulumi.getter
    def type(self) -> builtins.str:
        """
        服务器组的类型。取值如下：instance（默认值）：服务器类型。支持添加云服务器实例和已绑定云服务器实例的辅助网卡作为后端服务器。ip：IP地址类型。支持添加任何网络可达的VPC或IDC中的服务器作为后端服务器。
        """
        return pulumi.get(self, "type")

    @property
    @pulumi.getter(name="updatedTime")
    def updated_time(self) -> builtins.str:
        """
        后端服务器组的更新时间。
        """
        return pulumi.get(self, "updated_time")

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> builtins.str:
        """
        服务器组所属私有网络的ID。
        """
        return pulumi.get(self, "vpc_id")


class AwaitableGetNlbServerGroupResult(GetNlbServerGroupResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetNlbServerGroupResult(
            account_id=self.account_id,
            any_port_enabled=self.any_port_enabled,
            bypass_security_group_enabled=self.bypass_security_group_enabled,
            connection_drain_enabled=self.connection_drain_enabled,
            connection_drain_timeout=self.connection_drain_timeout,
            created_time=self.created_time,
            description=self.description,
            health_check=self.health_check,
            id=self.id,
            ip_address_version=self.ip_address_version,
            preserve_client_ip_enabled=self.preserve_client_ip_enabled,
            project_name=self.project_name,
            protocol=self.protocol,
            proxy_protocol_type=self.proxy_protocol_type,
            related_load_balancer_ids=self.related_load_balancer_ids,
            scheduler=self.scheduler,
            server_count=self.server_count,
            server_group_id=self.server_group_id,
            server_group_name=self.server_group_name,
            servers=self.servers,
            session_persistence_enabled=self.session_persistence_enabled,
            session_persistence_timeout=self.session_persistence_timeout,
            status=self.status,
            tags=self.tags,
            timestamp_remove_enabled=self.timestamp_remove_enabled,
            type=self.type,
            updated_time=self.updated_time,
            vpc_id=self.vpc_id)


def get_nlb_server_group(id: Optional[builtins.str] = None,
                         opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetNlbServerGroupResult:
    """
    Data Source schema for Byteplus::CLB::NLBServerGroup


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('bytepluscc:clb/getNlbServerGroup:getNlbServerGroup', __args__, opts=opts, typ=GetNlbServerGroupResult).value

    return AwaitableGetNlbServerGroupResult(
        account_id=pulumi.get(__ret__, 'account_id'),
        any_port_enabled=pulumi.get(__ret__, 'any_port_enabled'),
        bypass_security_group_enabled=pulumi.get(__ret__, 'bypass_security_group_enabled'),
        connection_drain_enabled=pulumi.get(__ret__, 'connection_drain_enabled'),
        connection_drain_timeout=pulumi.get(__ret__, 'connection_drain_timeout'),
        created_time=pulumi.get(__ret__, 'created_time'),
        description=pulumi.get(__ret__, 'description'),
        health_check=pulumi.get(__ret__, 'health_check'),
        id=pulumi.get(__ret__, 'id'),
        ip_address_version=pulumi.get(__ret__, 'ip_address_version'),
        preserve_client_ip_enabled=pulumi.get(__ret__, 'preserve_client_ip_enabled'),
        project_name=pulumi.get(__ret__, 'project_name'),
        protocol=pulumi.get(__ret__, 'protocol'),
        proxy_protocol_type=pulumi.get(__ret__, 'proxy_protocol_type'),
        related_load_balancer_ids=pulumi.get(__ret__, 'related_load_balancer_ids'),
        scheduler=pulumi.get(__ret__, 'scheduler'),
        server_count=pulumi.get(__ret__, 'server_count'),
        server_group_id=pulumi.get(__ret__, 'server_group_id'),
        server_group_name=pulumi.get(__ret__, 'server_group_name'),
        servers=pulumi.get(__ret__, 'servers'),
        session_persistence_enabled=pulumi.get(__ret__, 'session_persistence_enabled'),
        session_persistence_timeout=pulumi.get(__ret__, 'session_persistence_timeout'),
        status=pulumi.get(__ret__, 'status'),
        tags=pulumi.get(__ret__, 'tags'),
        timestamp_remove_enabled=pulumi.get(__ret__, 'timestamp_remove_enabled'),
        type=pulumi.get(__ret__, 'type'),
        updated_time=pulumi.get(__ret__, 'updated_time'),
        vpc_id=pulumi.get(__ret__, 'vpc_id'))
def get_nlb_server_group_output(id: Optional[pulumi.Input[builtins.str]] = None,
                                opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetNlbServerGroupResult]:
    """
    Data Source schema for Byteplus::CLB::NLBServerGroup


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('bytepluscc:clb/getNlbServerGroup:getNlbServerGroup', __args__, opts=opts, typ=GetNlbServerGroupResult)
    return __ret__.apply(lambda __response__: GetNlbServerGroupResult(
        account_id=pulumi.get(__response__, 'account_id'),
        any_port_enabled=pulumi.get(__response__, 'any_port_enabled'),
        bypass_security_group_enabled=pulumi.get(__response__, 'bypass_security_group_enabled'),
        connection_drain_enabled=pulumi.get(__response__, 'connection_drain_enabled'),
        connection_drain_timeout=pulumi.get(__response__, 'connection_drain_timeout'),
        created_time=pulumi.get(__response__, 'created_time'),
        description=pulumi.get(__response__, 'description'),
        health_check=pulumi.get(__response__, 'health_check'),
        id=pulumi.get(__response__, 'id'),
        ip_address_version=pulumi.get(__response__, 'ip_address_version'),
        preserve_client_ip_enabled=pulumi.get(__response__, 'preserve_client_ip_enabled'),
        project_name=pulumi.get(__response__, 'project_name'),
        protocol=pulumi.get(__response__, 'protocol'),
        proxy_protocol_type=pulumi.get(__response__, 'proxy_protocol_type'),
        related_load_balancer_ids=pulumi.get(__response__, 'related_load_balancer_ids'),
        scheduler=pulumi.get(__response__, 'scheduler'),
        server_count=pulumi.get(__response__, 'server_count'),
        server_group_id=pulumi.get(__response__, 'server_group_id'),
        server_group_name=pulumi.get(__response__, 'server_group_name'),
        servers=pulumi.get(__response__, 'servers'),
        session_persistence_enabled=pulumi.get(__response__, 'session_persistence_enabled'),
        session_persistence_timeout=pulumi.get(__response__, 'session_persistence_timeout'),
        status=pulumi.get(__response__, 'status'),
        tags=pulumi.get(__response__, 'tags'),
        timestamp_remove_enabled=pulumi.get(__response__, 'timestamp_remove_enabled'),
        type=pulumi.get(__response__, 'type'),
        updated_time=pulumi.get(__response__, 'updated_time'),
        vpc_id=pulumi.get(__response__, 'vpc_id')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetRuleResult',
    'AwaitableGetRuleResult',
    'get_rule',
    'get_rule_output',
]

@pulumi.output_type
class GetRuleResult:
    """
    A collection of values returned by getRule.
    """
    def __init__(__self__, alert_methods=None, alert_state=None, condition_operator=None, conditions=None, contact_group_ids=None, created_at=None, description=None, dimension_conditions=None, effect_end_at=None, effect_start_at=None, enable_state=None, evaluation_count=None, id=None, level=None, level_conditions=None, multiple_conditions=None, namespace=None, no_data=None, notification_id=None, notify_templates=None, original_dimensions=None, project_name=None, recovery_notify=None, regions=None, resource_type=None, rule_id=None, rule_name=None, rule_type=None, silence_time=None, sub_namespace=None, tags=None, updated_at=None, webhook=None, webhook_ids=None):
        if alert_methods and not isinstance(alert_methods, list):
            raise TypeError("Expected argument 'alert_methods' to be a list")
        pulumi.set(__self__, "alert_methods", alert_methods)
        if alert_state and not isinstance(alert_state, str):
            raise TypeError("Expected argument 'alert_state' to be a str")
        pulumi.set(__self__, "alert_state", alert_state)
        if condition_operator and not isinstance(condition_operator, str):
            raise TypeError("Expected argument 'condition_operator' to be a str")
        pulumi.set(__self__, "condition_operator", condition_operator)
        if conditions and not isinstance(conditions, list):
            raise TypeError("Expected argument 'conditions' to be a list")
        pulumi.set(__self__, "conditions", conditions)
        if contact_group_ids and not isinstance(contact_group_ids, list):
            raise TypeError("Expected argument 'contact_group_ids' to be a list")
        pulumi.set(__self__, "contact_group_ids", contact_group_ids)
        if created_at and not isinstance(created_at, str):
            raise TypeError("Expected argument 'created_at' to be a str")
        pulumi.set(__self__, "created_at", created_at)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if dimension_conditions and not isinstance(dimension_conditions, dict):
            raise TypeError("Expected argument 'dimension_conditions' to be a dict")
        pulumi.set(__self__, "dimension_conditions", dimension_conditions)
        if effect_end_at and not isinstance(effect_end_at, str):
            raise TypeError("Expected argument 'effect_end_at' to be a str")
        pulumi.set(__self__, "effect_end_at", effect_end_at)
        if effect_start_at and not isinstance(effect_start_at, str):
            raise TypeError("Expected argument 'effect_start_at' to be a str")
        pulumi.set(__self__, "effect_start_at", effect_start_at)
        if enable_state and not isinstance(enable_state, str):
            raise TypeError("Expected argument 'enable_state' to be a str")
        pulumi.set(__self__, "enable_state", enable_state)
        if evaluation_count and not isinstance(evaluation_count, int):
            raise TypeError("Expected argument 'evaluation_count' to be a int")
        pulumi.set(__self__, "evaluation_count", evaluation_count)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if level and not isinstance(level, str):
            raise TypeError("Expected argument 'level' to be a str")
        pulumi.set(__self__, "level", level)
        if level_conditions and not isinstance(level_conditions, list):
            raise TypeError("Expected argument 'level_conditions' to be a list")
        pulumi.set(__self__, "level_conditions", level_conditions)
        if multiple_conditions and not isinstance(multiple_conditions, bool):
            raise TypeError("Expected argument 'multiple_conditions' to be a bool")
        pulumi.set(__self__, "multiple_conditions", multiple_conditions)
        if namespace and not isinstance(namespace, str):
            raise TypeError("Expected argument 'namespace' to be a str")
        pulumi.set(__self__, "namespace", namespace)
        if no_data and not isinstance(no_data, dict):
            raise TypeError("Expected argument 'no_data' to be a dict")
        pulumi.set(__self__, "no_data", no_data)
        if notification_id and not isinstance(notification_id, str):
            raise TypeError("Expected argument 'notification_id' to be a str")
        pulumi.set(__self__, "notification_id", notification_id)
        if notify_templates and not isinstance(notify_templates, list):
            raise TypeError("Expected argument 'notify_templates' to be a list")
        pulumi.set(__self__, "notify_templates", notify_templates)
        if original_dimensions and not isinstance(original_dimensions, dict):
            raise TypeError("Expected argument 'original_dimensions' to be a dict")
        pulumi.set(__self__, "original_dimensions", original_dimensions)
        if project_name and not isinstance(project_name, str):
            raise TypeError("Expected argument 'project_name' to be a str")
        pulumi.set(__self__, "project_name", project_name)
        if recovery_notify and not isinstance(recovery_notify, dict):
            raise TypeError("Expected argument 'recovery_notify' to be a dict")
        pulumi.set(__self__, "recovery_notify", recovery_notify)
        if regions and not isinstance(regions, list):
            raise TypeError("Expected argument 'regions' to be a list")
        pulumi.set(__self__, "regions", regions)
        if resource_type and not isinstance(resource_type, str):
            raise TypeError("Expected argument 'resource_type' to be a str")
        pulumi.set(__self__, "resource_type", resource_type)
        if rule_id and not isinstance(rule_id, str):
            raise TypeError("Expected argument 'rule_id' to be a str")
        pulumi.set(__self__, "rule_id", rule_id)
        if rule_name and not isinstance(rule_name, str):
            raise TypeError("Expected argument 'rule_name' to be a str")
        pulumi.set(__self__, "rule_name", rule_name)
        if rule_type and not isinstance(rule_type, str):
            raise TypeError("Expected argument 'rule_type' to be a str")
        pulumi.set(__self__, "rule_type", rule_type)
        if silence_time and not isinstance(silence_time, int):
            raise TypeError("Expected argument 'silence_time' to be a int")
        pulumi.set(__self__, "silence_time", silence_time)
        if sub_namespace and not isinstance(sub_namespace, str):
            raise TypeError("Expected argument 'sub_namespace' to be a str")
        pulumi.set(__self__, "sub_namespace", sub_namespace)
        if tags and not isinstance(tags, list):
            raise TypeError("Expected argument 'tags' to be a list")
        pulumi.set(__self__, "tags", tags)
        if updated_at and not isinstance(updated_at, str):
            raise TypeError("Expected argument 'updated_at' to be a str")
        pulumi.set(__self__, "updated_at", updated_at)
        if webhook and not isinstance(webhook, str):
            raise TypeError("Expected argument 'webhook' to be a str")
        pulumi.set(__self__, "webhook", webhook)
        if webhook_ids and not isinstance(webhook_ids, list):
            raise TypeError("Expected argument 'webhook_ids' to be a list")
        pulumi.set(__self__, "webhook_ids", webhook_ids)

    @property
    @pulumi.getter(name="alertMethods")
    def alert_methods(self) -> Sequence[builtins.str]:
        """
        告警通知的方式。Email：邮件 Phone：电话 SMS：短信 Webhook：告警回调。
        """
        return pulumi.get(self, "alert_methods")

    @property
    @pulumi.getter(name="alertState")
    def alert_state(self) -> builtins.str:
        """
        告警状态。 alerting：告警中 normal：正常。
        """
        return pulumi.get(self, "alert_state")

    @property
    @pulumi.getter(name="conditionOperator")
    def condition_operator(self) -> builtins.str:
        """
        多指标判定条件。&&：多个指标同时成立才判定为触发告警,||：任意指标满足条件触发判定为告警。
        """
        return pulumi.get(self, "condition_operator")

    @property
    @pulumi.getter
    def conditions(self) -> Sequence['outputs.GetRuleConditionResult']:
        """
        告警条件。数组形式，支持填写多个指标判断语句，最多 10 个。
        """
        return pulumi.get(self, "conditions")

    @property
    @pulumi.getter(name="contactGroupIds")
    def contact_group_ids(self) -> Sequence[builtins.str]:
        """
        告警策略绑定的告警通知组 ID。
        """
        return pulumi.get(self, "contact_group_ids")

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> builtins.str:
        """
        告警策略创建时间，时间戳格式。
        """
        return pulumi.get(self, "created_at")

    @property
    @pulumi.getter
    def description(self) -> builtins.str:
        """
        告警策略描述信息。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="dimensionConditions")
    def dimension_conditions(self) -> 'outputs.GetRuleDimensionConditionsResult':
        """
        Dimension 配置。
        """
        return pulumi.get(self, "dimension_conditions")

    @property
    @pulumi.getter(name="effectEndAt")
    def effect_end_at(self) -> builtins.str:
        """
        策略生效的截止时间，格式为HH:MM。
        """
        return pulumi.get(self, "effect_end_at")

    @property
    @pulumi.getter(name="effectStartAt")
    def effect_start_at(self) -> builtins.str:
        """
        告警策略生效的开始时间，格式为HH:MM。
        """
        return pulumi.get(self, "effect_start_at")

    @property
    @pulumi.getter(name="enableState")
    def enable_state(self) -> builtins.str:
        """
        告警策略的开启状态。,enable：开启,disable：禁用
        """
        return pulumi.get(self, "enable_state")

    @property
    @pulumi.getter(name="evaluationCount")
    def evaluation_count(self) -> builtins.int:
        """
        触发告警需要持续的周期。单位为分钟。
        """
        return pulumi.get(self, "evaluation_count")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        Uniquely identifies the resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def level(self) -> builtins.str:
        """
        告警级别。critical：严重,warning：警告,notice：通知
        """
        return pulumi.get(self, "level")

    @property
    @pulumi.getter(name="levelConditions")
    def level_conditions(self) -> Sequence['outputs.GetRuleLevelConditionResult']:
        """
        告警分级配置。
        """
        return pulumi.get(self, "level_conditions")

    @property
    @pulumi.getter(name="multipleConditions")
    def multiple_conditions(self) -> builtins.bool:
        """
        告警策略是否用多指标。true：多指标,false：单指标（默认）。
        """
        return pulumi.get(self, "multiple_conditions")

    @property
    @pulumi.getter
    def namespace(self) -> builtins.str:
        """
        监控指标所属的云产品。详情请参见 云产品监控指标 下各产品的 Namespace。
        """
        return pulumi.get(self, "namespace")

    @property
    @pulumi.getter(name="noData")
    def no_data(self) -> 'outputs.GetRuleNoDataResult':
        """
        无数据告警。
        """
        return pulumi.get(self, "no_data")

    @property
    @pulumi.getter(name="notificationId")
    def notification_id(self) -> builtins.str:
        """
        通知策略 ID。
        """
        return pulumi.get(self, "notification_id")

    @property
    @pulumi.getter(name="notifyTemplates")
    def notify_templates(self) -> Sequence['outputs.GetRuleNotifyTemplateResult']:
        """
        通知模版配置。
        """
        return pulumi.get(self, "notify_templates")

    @property
    @pulumi.getter(name="originalDimensions")
    def original_dimensions(self) -> 'outputs.GetRuleOriginalDimensionsResult':
        """
        告警策略检测的资源 ID。
        """
        return pulumi.get(self, "original_dimensions")

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> builtins.str:
        """
        告警策略所属项目。
        """
        return pulumi.get(self, "project_name")

    @property
    @pulumi.getter(name="recoveryNotify")
    def recovery_notify(self) -> 'outputs.GetRuleRecoveryNotifyResult':
        """
        告警恢复通知。
        """
        return pulumi.get(self, "recovery_notify")

    @property
    @pulumi.getter
    def regions(self) -> Sequence[builtins.str]:
        """
        云产品所属可用区 ID。
        """
        return pulumi.get(self, "regions")

    @property
    @pulumi.getter(name="resourceType")
    def resource_type(self) -> builtins.str:
        """
        告警策略检测的资源类型。
        """
        return pulumi.get(self, "resource_type")

    @property
    @pulumi.getter(name="ruleId")
    def rule_id(self) -> builtins.str:
        """
        告警策略 ID。
        """
        return pulumi.get(self, "rule_id")

    @property
    @pulumi.getter(name="ruleName")
    def rule_name(self) -> builtins.str:
        """
        告警策略名称。
        """
        return pulumi.get(self, "rule_name")

    @property
    @pulumi.getter(name="ruleType")
    def rule_type(self) -> builtins.str:
        """
        告警策略的类型。static：手动选择。dynamic：通过资源名称、项目和标签选择。
        """
        return pulumi.get(self, "rule_type")

    @property
    @pulumi.getter(name="silenceTime")
    def silence_time(self) -> builtins.int:
        """
        告警发送周期。单位为分钟。支持配置为 5、10、15、30、60、180、360、720、1440。
        """
        return pulumi.get(self, "silence_time")

    @property
    @pulumi.getter(name="subNamespace")
    def sub_namespace(self) -> builtins.str:
        """
        此策略引用的指标所属的维度。详情请参见 云产品监控指标 下各产品的 SubNamespace。
        """
        return pulumi.get(self, "sub_namespace")

    @property
    @pulumi.getter
    def tags(self) -> Sequence['outputs.GetRuleTagResult']:
        """
        告警策略绑定 Tag。
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> builtins.str:
        """
        告警策略更新时间，时间戳格式。
        """
        return pulumi.get(self, "updated_at")

    @property
    @pulumi.getter
    def webhook(self) -> builtins.str:
        """
        告警策略绑定的告警回调 URL 地址。
        """
        return pulumi.get(self, "webhook")

    @property
    @pulumi.getter(name="webhookIds")
    def webhook_ids(self) -> Sequence[builtins.str]:
        """
        告警发生时告警回调 ID 列表。
        """
        return pulumi.get(self, "webhook_ids")


class AwaitableGetRuleResult(GetRuleResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetRuleResult(
            alert_methods=self.alert_methods,
            alert_state=self.alert_state,
            condition_operator=self.condition_operator,
            conditions=self.conditions,
            contact_group_ids=self.contact_group_ids,
            created_at=self.created_at,
            description=self.description,
            dimension_conditions=self.dimension_conditions,
            effect_end_at=self.effect_end_at,
            effect_start_at=self.effect_start_at,
            enable_state=self.enable_state,
            evaluation_count=self.evaluation_count,
            id=self.id,
            level=self.level,
            level_conditions=self.level_conditions,
            multiple_conditions=self.multiple_conditions,
            namespace=self.namespace,
            no_data=self.no_data,
            notification_id=self.notification_id,
            notify_templates=self.notify_templates,
            original_dimensions=self.original_dimensions,
            project_name=self.project_name,
            recovery_notify=self.recovery_notify,
            regions=self.regions,
            resource_type=self.resource_type,
            rule_id=self.rule_id,
            rule_name=self.rule_name,
            rule_type=self.rule_type,
            silence_time=self.silence_time,
            sub_namespace=self.sub_namespace,
            tags=self.tags,
            updated_at=self.updated_at,
            webhook=self.webhook,
            webhook_ids=self.webhook_ids)


def get_rule(id: Optional[builtins.str] = None,
             opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetRuleResult:
    """
    Data Source schema for Byteplus::CloudMonitor::Rule


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('bytepluscc:cloudmonitor/getRule:getRule', __args__, opts=opts, typ=GetRuleResult).value

    return AwaitableGetRuleResult(
        alert_methods=pulumi.get(__ret__, 'alert_methods'),
        alert_state=pulumi.get(__ret__, 'alert_state'),
        condition_operator=pulumi.get(__ret__, 'condition_operator'),
        conditions=pulumi.get(__ret__, 'conditions'),
        contact_group_ids=pulumi.get(__ret__, 'contact_group_ids'),
        created_at=pulumi.get(__ret__, 'created_at'),
        description=pulumi.get(__ret__, 'description'),
        dimension_conditions=pulumi.get(__ret__, 'dimension_conditions'),
        effect_end_at=pulumi.get(__ret__, 'effect_end_at'),
        effect_start_at=pulumi.get(__ret__, 'effect_start_at'),
        enable_state=pulumi.get(__ret__, 'enable_state'),
        evaluation_count=pulumi.get(__ret__, 'evaluation_count'),
        id=pulumi.get(__ret__, 'id'),
        level=pulumi.get(__ret__, 'level'),
        level_conditions=pulumi.get(__ret__, 'level_conditions'),
        multiple_conditions=pulumi.get(__ret__, 'multiple_conditions'),
        namespace=pulumi.get(__ret__, 'namespace'),
        no_data=pulumi.get(__ret__, 'no_data'),
        notification_id=pulumi.get(__ret__, 'notification_id'),
        notify_templates=pulumi.get(__ret__, 'notify_templates'),
        original_dimensions=pulumi.get(__ret__, 'original_dimensions'),
        project_name=pulumi.get(__ret__, 'project_name'),
        recovery_notify=pulumi.get(__ret__, 'recovery_notify'),
        regions=pulumi.get(__ret__, 'regions'),
        resource_type=pulumi.get(__ret__, 'resource_type'),
        rule_id=pulumi.get(__ret__, 'rule_id'),
        rule_name=pulumi.get(__ret__, 'rule_name'),
        rule_type=pulumi.get(__ret__, 'rule_type'),
        silence_time=pulumi.get(__ret__, 'silence_time'),
        sub_namespace=pulumi.get(__ret__, 'sub_namespace'),
        tags=pulumi.get(__ret__, 'tags'),
        updated_at=pulumi.get(__ret__, 'updated_at'),
        webhook=pulumi.get(__ret__, 'webhook'),
        webhook_ids=pulumi.get(__ret__, 'webhook_ids'))
def get_rule_output(id: Optional[pulumi.Input[builtins.str]] = None,
                    opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetRuleResult]:
    """
    Data Source schema for Byteplus::CloudMonitor::Rule


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('bytepluscc:cloudmonitor/getRule:getRule', __args__, opts=opts, typ=GetRuleResult)
    return __ret__.apply(lambda __response__: GetRuleResult(
        alert_methods=pulumi.get(__response__, 'alert_methods'),
        alert_state=pulumi.get(__response__, 'alert_state'),
        condition_operator=pulumi.get(__response__, 'condition_operator'),
        conditions=pulumi.get(__response__, 'conditions'),
        contact_group_ids=pulumi.get(__response__, 'contact_group_ids'),
        created_at=pulumi.get(__response__, 'created_at'),
        description=pulumi.get(__response__, 'description'),
        dimension_conditions=pulumi.get(__response__, 'dimension_conditions'),
        effect_end_at=pulumi.get(__response__, 'effect_end_at'),
        effect_start_at=pulumi.get(__response__, 'effect_start_at'),
        enable_state=pulumi.get(__response__, 'enable_state'),
        evaluation_count=pulumi.get(__response__, 'evaluation_count'),
        id=pulumi.get(__response__, 'id'),
        level=pulumi.get(__response__, 'level'),
        level_conditions=pulumi.get(__response__, 'level_conditions'),
        multiple_conditions=pulumi.get(__response__, 'multiple_conditions'),
        namespace=pulumi.get(__response__, 'namespace'),
        no_data=pulumi.get(__response__, 'no_data'),
        notification_id=pulumi.get(__response__, 'notification_id'),
        notify_templates=pulumi.get(__response__, 'notify_templates'),
        original_dimensions=pulumi.get(__response__, 'original_dimensions'),
        project_name=pulumi.get(__response__, 'project_name'),
        recovery_notify=pulumi.get(__response__, 'recovery_notify'),
        regions=pulumi.get(__response__, 'regions'),
        resource_type=pulumi.get(__response__, 'resource_type'),
        rule_id=pulumi.get(__response__, 'rule_id'),
        rule_name=pulumi.get(__response__, 'rule_name'),
        rule_type=pulumi.get(__response__, 'rule_type'),
        silence_time=pulumi.get(__response__, 'silence_time'),
        sub_namespace=pulumi.get(__response__, 'sub_namespace'),
        tags=pulumi.get(__response__, 'tags'),
        updated_at=pulumi.get(__response__, 'updated_at'),
        webhook=pulumi.get(__response__, 'webhook'),
        webhook_ids=pulumi.get(__response__, 'webhook_ids')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['RegistryArgs', 'Registry']

@pulumi.input_type
class RegistryArgs:
    def __init__(__self__, *,
                 name: pulumi.Input[builtins.str],
                 project: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['RegistryTagArgs']]]] = None,
                 type: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a Registry resource.
        :param pulumi.Input[builtins.str] name: 标准版实例名称，同一个地域下，名称必须唯一。支持小写英文字母、数字、短划线（-）且数字不能在首位，短划线（-）不能在首位或末位，长度限制为 3～30 个字符。
        :param pulumi.Input[builtins.str] project: 填写实例需要关联的项目。一个实例仅支持关联一个项目
        :param pulumi.Input[builtins.str] type: 不填写默认创建标准版实例。Enterprise：标准版，Micro：小微版
        """
        pulumi.set(__self__, "name", name)
        if project is not None:
            pulumi.set(__self__, "project", project)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if type is not None:
            pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter
    def name(self) -> pulumi.Input[builtins.str]:
        """
        标准版实例名称，同一个地域下，名称必须唯一。支持小写英文字母、数字、短划线（-）且数字不能在首位，短划线（-）不能在首位或末位，长度限制为 3～30 个字符。
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def project(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        填写实例需要关联的项目。一个实例仅支持关联一个项目
        """
        return pulumi.get(self, "project")

    @project.setter
    def project(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "project", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['RegistryTagArgs']]]]:
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['RegistryTagArgs']]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        不填写默认创建标准版实例。Enterprise：标准版，Micro：小微版
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "type", value)


@pulumi.input_type
class _RegistryState:
    def __init__(__self__, *,
                 charge_type: Optional[pulumi.Input[builtins.str]] = None,
                 created_time: Optional[pulumi.Input[builtins.str]] = None,
                 expire_time: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 project: Optional[pulumi.Input[builtins.str]] = None,
                 proxy_cache: Optional[pulumi.Input['RegistryProxyCacheArgs']] = None,
                 proxy_cache_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 renew_type: Optional[pulumi.Input[builtins.str]] = None,
                 status: Optional[pulumi.Input['RegistryStatusArgs']] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['RegistryTagArgs']]]] = None,
                 type: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering Registry resources.
        :param pulumi.Input[builtins.str] charge_type: 镜像仓库实例的付费类型，目前仅支持 PostCharge按量付费模式。
        :param pulumi.Input[builtins.str] created_time: 创建镜像仓库实例的时间。
        :param pulumi.Input[builtins.str] expire_time: 仅计费类型为HybridCharge有值，实例到期时间
        :param pulumi.Input[builtins.str] name: 标准版实例名称，同一个地域下，名称必须唯一。支持小写英文字母、数字、短划线（-）且数字不能在首位，短划线（-）不能在首位或末位，长度限制为 3～30 个字符。
        :param pulumi.Input[builtins.str] project: 填写实例需要关联的项目。一个实例仅支持关联一个项目
        :param pulumi.Input['RegistryProxyCacheArgs'] proxy_cache: ProxyCache配置，设置为ProxyCache时必填
        :param pulumi.Input[builtins.bool] proxy_cache_enabled: 是否设置为ProxyCache实例
        :param pulumi.Input[builtins.str] renew_type: 仅计费类型为HybridCharge有值，实例自动续费类型
        :param pulumi.Input['RegistryStatusArgs'] status: 镜像仓库实例状态，由 Phase 和 Conditions 组成。合法的 Phase 和 Conditions 组合如下所示：{Creating, [Progressing]}：创建中,{Running, [Ok]}：运行中,{Running, [Degraded]}：运行中,{Stopped, [Balance]}：欠费关停,{Stopped, [Released]}：待回收,{Stopped, [Released, Balance]}：欠费关停,{Starting, [Progressing]}：启动中,{Deleting, [Progressing]}：销毁中,{Failed, [Unknown]}：异常
        :param pulumi.Input[builtins.str] type: 不填写默认创建标准版实例。Enterprise：标准版，Micro：小微版
        """
        if charge_type is not None:
            pulumi.set(__self__, "charge_type", charge_type)
        if created_time is not None:
            pulumi.set(__self__, "created_time", created_time)
        if expire_time is not None:
            pulumi.set(__self__, "expire_time", expire_time)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if project is not None:
            pulumi.set(__self__, "project", project)
        if proxy_cache is not None:
            pulumi.set(__self__, "proxy_cache", proxy_cache)
        if proxy_cache_enabled is not None:
            pulumi.set(__self__, "proxy_cache_enabled", proxy_cache_enabled)
        if renew_type is not None:
            pulumi.set(__self__, "renew_type", renew_type)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if type is not None:
            pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter(name="chargeType")
    def charge_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        镜像仓库实例的付费类型，目前仅支持 PostCharge按量付费模式。
        """
        return pulumi.get(self, "charge_type")

    @charge_type.setter
    def charge_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "charge_type", value)

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        创建镜像仓库实例的时间。
        """
        return pulumi.get(self, "created_time")

    @created_time.setter
    def created_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "created_time", value)

    @property
    @pulumi.getter(name="expireTime")
    def expire_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        仅计费类型为HybridCharge有值，实例到期时间
        """
        return pulumi.get(self, "expire_time")

    @expire_time.setter
    def expire_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "expire_time", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        标准版实例名称，同一个地域下，名称必须唯一。支持小写英文字母、数字、短划线（-）且数字不能在首位，短划线（-）不能在首位或末位，长度限制为 3～30 个字符。
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def project(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        填写实例需要关联的项目。一个实例仅支持关联一个项目
        """
        return pulumi.get(self, "project")

    @project.setter
    def project(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "project", value)

    @property
    @pulumi.getter(name="proxyCache")
    def proxy_cache(self) -> Optional[pulumi.Input['RegistryProxyCacheArgs']]:
        """
        ProxyCache配置，设置为ProxyCache时必填
        """
        return pulumi.get(self, "proxy_cache")

    @proxy_cache.setter
    def proxy_cache(self, value: Optional[pulumi.Input['RegistryProxyCacheArgs']]):
        pulumi.set(self, "proxy_cache", value)

    @property
    @pulumi.getter(name="proxyCacheEnabled")
    def proxy_cache_enabled(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        是否设置为ProxyCache实例
        """
        return pulumi.get(self, "proxy_cache_enabled")

    @proxy_cache_enabled.setter
    def proxy_cache_enabled(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "proxy_cache_enabled", value)

    @property
    @pulumi.getter(name="renewType")
    def renew_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        仅计费类型为HybridCharge有值，实例自动续费类型
        """
        return pulumi.get(self, "renew_type")

    @renew_type.setter
    def renew_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "renew_type", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input['RegistryStatusArgs']]:
        """
        镜像仓库实例状态，由 Phase 和 Conditions 组成。合法的 Phase 和 Conditions 组合如下所示：{Creating, [Progressing]}：创建中,{Running, [Ok]}：运行中,{Running, [Degraded]}：运行中,{Stopped, [Balance]}：欠费关停,{Stopped, [Released]}：待回收,{Stopped, [Released, Balance]}：欠费关停,{Starting, [Progressing]}：启动中,{Deleting, [Progressing]}：销毁中,{Failed, [Unknown]}：异常
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input['RegistryStatusArgs']]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['RegistryTagArgs']]]]:
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['RegistryTagArgs']]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        不填写默认创建标准版实例。Enterprise：标准版，Micro：小微版
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "type", value)


@pulumi.type_token("bytepluscc:cr/registry:Registry")
class Registry(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 project: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['RegistryTagArgs', 'RegistryTagArgsDict']]]]] = None,
                 type: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        镜像仓库（Container Registry，CR）提供安全高可用的容器镜像、Helm Chart 等符合 OCI 标准的云原生制品托管服务，方便企业用户管理容器镜像和 Helm Chart 的全生命周期。

        ## Example Usage

        ```python
        import pulumi
        import pulumi_bytepluscc as bytepluscc

        c_r_registry_demo = bytepluscc.cr.Registry("CRRegistryDemo",
            project="default",
            name="test",
            type="Enterprise",
            tags=[{
                "key": "env",
                "value": "test",
            }])
        ```

        ## Import

        ```sh
        $ pulumi import bytepluscc:cr/registry:Registry example "name"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] name: 标准版实例名称，同一个地域下，名称必须唯一。支持小写英文字母、数字、短划线（-）且数字不能在首位，短划线（-）不能在首位或末位，长度限制为 3～30 个字符。
        :param pulumi.Input[builtins.str] project: 填写实例需要关联的项目。一个实例仅支持关联一个项目
        :param pulumi.Input[builtins.str] type: 不填写默认创建标准版实例。Enterprise：标准版，Micro：小微版
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: RegistryArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        镜像仓库（Container Registry，CR）提供安全高可用的容器镜像、Helm Chart 等符合 OCI 标准的云原生制品托管服务，方便企业用户管理容器镜像和 Helm Chart 的全生命周期。

        ## Example Usage

        ```python
        import pulumi
        import pulumi_bytepluscc as bytepluscc

        c_r_registry_demo = bytepluscc.cr.Registry("CRRegistryDemo",
            project="default",
            name="test",
            type="Enterprise",
            tags=[{
                "key": "env",
                "value": "test",
            }])
        ```

        ## Import

        ```sh
        $ pulumi import bytepluscc:cr/registry:Registry example "name"
        ```

        :param str resource_name: The name of the resource.
        :param RegistryArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(RegistryArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 project: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['RegistryTagArgs', 'RegistryTagArgsDict']]]]] = None,
                 type: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = RegistryArgs.__new__(RegistryArgs)

            if name is None and not opts.urn:
                raise TypeError("Missing required property 'name'")
            __props__.__dict__["name"] = name
            __props__.__dict__["project"] = project
            __props__.__dict__["tags"] = tags
            __props__.__dict__["type"] = type
            __props__.__dict__["charge_type"] = None
            __props__.__dict__["created_time"] = None
            __props__.__dict__["expire_time"] = None
            __props__.__dict__["proxy_cache"] = None
            __props__.__dict__["proxy_cache_enabled"] = None
            __props__.__dict__["renew_type"] = None
            __props__.__dict__["status"] = None
        super(Registry, __self__).__init__(
            'bytepluscc:cr/registry:Registry',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            charge_type: Optional[pulumi.Input[builtins.str]] = None,
            created_time: Optional[pulumi.Input[builtins.str]] = None,
            expire_time: Optional[pulumi.Input[builtins.str]] = None,
            name: Optional[pulumi.Input[builtins.str]] = None,
            project: Optional[pulumi.Input[builtins.str]] = None,
            proxy_cache: Optional[pulumi.Input[Union['RegistryProxyCacheArgs', 'RegistryProxyCacheArgsDict']]] = None,
            proxy_cache_enabled: Optional[pulumi.Input[builtins.bool]] = None,
            renew_type: Optional[pulumi.Input[builtins.str]] = None,
            status: Optional[pulumi.Input[Union['RegistryStatusArgs', 'RegistryStatusArgsDict']]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['RegistryTagArgs', 'RegistryTagArgsDict']]]]] = None,
            type: Optional[pulumi.Input[builtins.str]] = None) -> 'Registry':
        """
        Get an existing Registry resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] charge_type: 镜像仓库实例的付费类型，目前仅支持 PostCharge按量付费模式。
        :param pulumi.Input[builtins.str] created_time: 创建镜像仓库实例的时间。
        :param pulumi.Input[builtins.str] expire_time: 仅计费类型为HybridCharge有值，实例到期时间
        :param pulumi.Input[builtins.str] name: 标准版实例名称，同一个地域下，名称必须唯一。支持小写英文字母、数字、短划线（-）且数字不能在首位，短划线（-）不能在首位或末位，长度限制为 3～30 个字符。
        :param pulumi.Input[builtins.str] project: 填写实例需要关联的项目。一个实例仅支持关联一个项目
        :param pulumi.Input[Union['RegistryProxyCacheArgs', 'RegistryProxyCacheArgsDict']] proxy_cache: ProxyCache配置，设置为ProxyCache时必填
        :param pulumi.Input[builtins.bool] proxy_cache_enabled: 是否设置为ProxyCache实例
        :param pulumi.Input[builtins.str] renew_type: 仅计费类型为HybridCharge有值，实例自动续费类型
        :param pulumi.Input[Union['RegistryStatusArgs', 'RegistryStatusArgsDict']] status: 镜像仓库实例状态，由 Phase 和 Conditions 组成。合法的 Phase 和 Conditions 组合如下所示：{Creating, [Progressing]}：创建中,{Running, [Ok]}：运行中,{Running, [Degraded]}：运行中,{Stopped, [Balance]}：欠费关停,{Stopped, [Released]}：待回收,{Stopped, [Released, Balance]}：欠费关停,{Starting, [Progressing]}：启动中,{Deleting, [Progressing]}：销毁中,{Failed, [Unknown]}：异常
        :param pulumi.Input[builtins.str] type: 不填写默认创建标准版实例。Enterprise：标准版，Micro：小微版
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _RegistryState.__new__(_RegistryState)

        __props__.__dict__["charge_type"] = charge_type
        __props__.__dict__["created_time"] = created_time
        __props__.__dict__["expire_time"] = expire_time
        __props__.__dict__["name"] = name
        __props__.__dict__["project"] = project
        __props__.__dict__["proxy_cache"] = proxy_cache
        __props__.__dict__["proxy_cache_enabled"] = proxy_cache_enabled
        __props__.__dict__["renew_type"] = renew_type
        __props__.__dict__["status"] = status
        __props__.__dict__["tags"] = tags
        __props__.__dict__["type"] = type
        return Registry(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="chargeType")
    def charge_type(self) -> pulumi.Output[builtins.str]:
        """
        镜像仓库实例的付费类型，目前仅支持 PostCharge按量付费模式。
        """
        return pulumi.get(self, "charge_type")

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> pulumi.Output[builtins.str]:
        """
        创建镜像仓库实例的时间。
        """
        return pulumi.get(self, "created_time")

    @property
    @pulumi.getter(name="expireTime")
    def expire_time(self) -> pulumi.Output[builtins.str]:
        """
        仅计费类型为HybridCharge有值，实例到期时间
        """
        return pulumi.get(self, "expire_time")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[builtins.str]:
        """
        标准版实例名称，同一个地域下，名称必须唯一。支持小写英文字母、数字、短划线（-）且数字不能在首位，短划线（-）不能在首位或末位，长度限制为 3～30 个字符。
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def project(self) -> pulumi.Output[builtins.str]:
        """
        填写实例需要关联的项目。一个实例仅支持关联一个项目
        """
        return pulumi.get(self, "project")

    @property
    @pulumi.getter(name="proxyCache")
    def proxy_cache(self) -> pulumi.Output['outputs.RegistryProxyCache']:
        """
        ProxyCache配置，设置为ProxyCache时必填
        """
        return pulumi.get(self, "proxy_cache")

    @property
    @pulumi.getter(name="proxyCacheEnabled")
    def proxy_cache_enabled(self) -> pulumi.Output[builtins.bool]:
        """
        是否设置为ProxyCache实例
        """
        return pulumi.get(self, "proxy_cache_enabled")

    @property
    @pulumi.getter(name="renewType")
    def renew_type(self) -> pulumi.Output[builtins.str]:
        """
        仅计费类型为HybridCharge有值，实例自动续费类型
        """
        return pulumi.get(self, "renew_type")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output['outputs.RegistryStatus']:
        """
        镜像仓库实例状态，由 Phase 和 Conditions 组成。合法的 Phase 和 Conditions 组合如下所示：{Creating, [Progressing]}：创建中,{Running, [Ok]}：运行中,{Running, [Degraded]}：运行中,{Stopped, [Balance]}：欠费关停,{Stopped, [Released]}：待回收,{Stopped, [Released, Balance]}：欠费关停,{Starting, [Progressing]}：启动中,{Deleting, [Progressing]}：销毁中,{Failed, [Unknown]}：异常
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Sequence['outputs.RegistryTag']]:
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter
    def type(self) -> pulumi.Output[builtins.str]:
        """
        不填写默认创建标准版实例。Enterprise：标准版，Micro：小微版
        """
        return pulumi.get(self, "type")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetLoadBalancerResult',
    'AwaitableGetLoadBalancerResult',
    'get_load_balancer',
    'get_load_balancer_output',
]

@pulumi.output_type
class GetLoadBalancerResult:
    """
    A collection of values returned by getLoadBalancer.
    """
    def __init__(__self__, address_ip_version=None, bandwidth_package_id=None, business_status=None, create_time=None, delete_protection=None, deleted_time=None, description=None, dns_name=None, eip_billing_config=None, global_accelerator=None, id=None, ipv6_eip_billing_config=None, load_balancer_billing_type=None, load_balancer_edition=None, load_balancer_id=None, load_balancer_name=None, lock_reason=None, modification_protection_reason=None, modification_protection_status=None, overdue_time=None, project_name=None, status=None, tags=None, type=None, update_time=None, vpc_id=None, waf_instance_id=None, waf_protected_domain=None, waf_protection_enabled=None, zone_mappings=None):
        if address_ip_version and not isinstance(address_ip_version, str):
            raise TypeError("Expected argument 'address_ip_version' to be a str")
        pulumi.set(__self__, "address_ip_version", address_ip_version)
        if bandwidth_package_id and not isinstance(bandwidth_package_id, str):
            raise TypeError("Expected argument 'bandwidth_package_id' to be a str")
        pulumi.set(__self__, "bandwidth_package_id", bandwidth_package_id)
        if business_status and not isinstance(business_status, str):
            raise TypeError("Expected argument 'business_status' to be a str")
        pulumi.set(__self__, "business_status", business_status)
        if create_time and not isinstance(create_time, str):
            raise TypeError("Expected argument 'create_time' to be a str")
        pulumi.set(__self__, "create_time", create_time)
        if delete_protection and not isinstance(delete_protection, str):
            raise TypeError("Expected argument 'delete_protection' to be a str")
        pulumi.set(__self__, "delete_protection", delete_protection)
        if deleted_time and not isinstance(deleted_time, str):
            raise TypeError("Expected argument 'deleted_time' to be a str")
        pulumi.set(__self__, "deleted_time", deleted_time)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if dns_name and not isinstance(dns_name, str):
            raise TypeError("Expected argument 'dns_name' to be a str")
        pulumi.set(__self__, "dns_name", dns_name)
        if eip_billing_config and not isinstance(eip_billing_config, dict):
            raise TypeError("Expected argument 'eip_billing_config' to be a dict")
        pulumi.set(__self__, "eip_billing_config", eip_billing_config)
        if global_accelerator and not isinstance(global_accelerator, dict):
            raise TypeError("Expected argument 'global_accelerator' to be a dict")
        pulumi.set(__self__, "global_accelerator", global_accelerator)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ipv6_eip_billing_config and not isinstance(ipv6_eip_billing_config, dict):
            raise TypeError("Expected argument 'ipv6_eip_billing_config' to be a dict")
        pulumi.set(__self__, "ipv6_eip_billing_config", ipv6_eip_billing_config)
        if load_balancer_billing_type and not isinstance(load_balancer_billing_type, int):
            raise TypeError("Expected argument 'load_balancer_billing_type' to be a int")
        pulumi.set(__self__, "load_balancer_billing_type", load_balancer_billing_type)
        if load_balancer_edition and not isinstance(load_balancer_edition, str):
            raise TypeError("Expected argument 'load_balancer_edition' to be a str")
        pulumi.set(__self__, "load_balancer_edition", load_balancer_edition)
        if load_balancer_id and not isinstance(load_balancer_id, str):
            raise TypeError("Expected argument 'load_balancer_id' to be a str")
        pulumi.set(__self__, "load_balancer_id", load_balancer_id)
        if load_balancer_name and not isinstance(load_balancer_name, str):
            raise TypeError("Expected argument 'load_balancer_name' to be a str")
        pulumi.set(__self__, "load_balancer_name", load_balancer_name)
        if lock_reason and not isinstance(lock_reason, str):
            raise TypeError("Expected argument 'lock_reason' to be a str")
        pulumi.set(__self__, "lock_reason", lock_reason)
        if modification_protection_reason and not isinstance(modification_protection_reason, str):
            raise TypeError("Expected argument 'modification_protection_reason' to be a str")
        pulumi.set(__self__, "modification_protection_reason", modification_protection_reason)
        if modification_protection_status and not isinstance(modification_protection_status, str):
            raise TypeError("Expected argument 'modification_protection_status' to be a str")
        pulumi.set(__self__, "modification_protection_status", modification_protection_status)
        if overdue_time and not isinstance(overdue_time, str):
            raise TypeError("Expected argument 'overdue_time' to be a str")
        pulumi.set(__self__, "overdue_time", overdue_time)
        if project_name and not isinstance(project_name, str):
            raise TypeError("Expected argument 'project_name' to be a str")
        pulumi.set(__self__, "project_name", project_name)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if tags and not isinstance(tags, list):
            raise TypeError("Expected argument 'tags' to be a list")
        pulumi.set(__self__, "tags", tags)
        if type and not isinstance(type, str):
            raise TypeError("Expected argument 'type' to be a str")
        pulumi.set(__self__, "type", type)
        if update_time and not isinstance(update_time, str):
            raise TypeError("Expected argument 'update_time' to be a str")
        pulumi.set(__self__, "update_time", update_time)
        if vpc_id and not isinstance(vpc_id, str):
            raise TypeError("Expected argument 'vpc_id' to be a str")
        pulumi.set(__self__, "vpc_id", vpc_id)
        if waf_instance_id and not isinstance(waf_instance_id, str):
            raise TypeError("Expected argument 'waf_instance_id' to be a str")
        pulumi.set(__self__, "waf_instance_id", waf_instance_id)
        if waf_protected_domain and not isinstance(waf_protected_domain, str):
            raise TypeError("Expected argument 'waf_protected_domain' to be a str")
        pulumi.set(__self__, "waf_protected_domain", waf_protected_domain)
        if waf_protection_enabled and not isinstance(waf_protection_enabled, str):
            raise TypeError("Expected argument 'waf_protection_enabled' to be a str")
        pulumi.set(__self__, "waf_protection_enabled", waf_protection_enabled)
        if zone_mappings and not isinstance(zone_mappings, list):
            raise TypeError("Expected argument 'zone_mappings' to be a list")
        pulumi.set(__self__, "zone_mappings", zone_mappings)

    @property
    @pulumi.getter(name="addressIpVersion")
    def address_ip_version(self) -> builtins.str:
        """
        ALB 实例的 IP 类型。IPv4：IPv4 类型；DualStack：IPv4&IPv6 双栈类型。
        """
        return pulumi.get(self, "address_ip_version")

    @property
    @pulumi.getter(name="bandwidthPackageId")
    def bandwidth_package_id(self) -> builtins.str:
        """
        绑定的共享带宽包ID，可实现带宽共享。
        """
        return pulumi.get(self, "bandwidth_package_id")

    @property
    @pulumi.getter(name="businessStatus")
    def business_status(self) -> builtins.str:
        """
        ALB 实例的服务状态。Normal：正常；FinancialLocked：因欠费被锁定。
        """
        return pulumi.get(self, "business_status")

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> builtins.str:
        """
        ALB 实例的创建时间。
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter(name="deleteProtection")
    def delete_protection(self) -> builtins.str:
        """
        删除保护开关。on：开启；off：关闭。
        """
        return pulumi.get(self, "delete_protection")

    @property
    @pulumi.getter(name="deletedTime")
    def deleted_time(self) -> builtins.str:
        """
        ALB 实例的预期回收时间。该参数只有实例处于 FinancialLocked 状态时有返回值。
        """
        return pulumi.get(self, "deleted_time")

    @property
    @pulumi.getter
    def description(self) -> builtins.str:
        """
        ALB 实例的描述。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="dnsName")
    def dns_name(self) -> builtins.str:
        """
        DNS域名。
        """
        return pulumi.get(self, "dns_name")

    @property
    @pulumi.getter(name="eipBillingConfig")
    def eip_billing_config(self) -> 'outputs.GetLoadBalancerEipBillingConfigResult':
        """
        公网IP的计费配置，仅适用于公网实例。
        """
        return pulumi.get(self, "eip_billing_config")

    @property
    @pulumi.getter(name="globalAccelerator")
    def global_accelerator(self) -> 'outputs.GetLoadBalancerGlobalAcceleratorResult':
        """
        全球加速器配置，用于提升跨地域访问速度。
        """
        return pulumi.get(self, "global_accelerator")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        Uniquely identifies the resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="ipv6EipBillingConfig")
    def ipv6_eip_billing_config(self) -> 'outputs.GetLoadBalancerIpv6EipBillingConfigResult':
        """
        IPv6公网IP的计費配置，仅适用于公网实例。
        """
        return pulumi.get(self, "ipv6_eip_billing_config")

    @property
    @pulumi.getter(name="loadBalancerBillingType")
    def load_balancer_billing_type(self) -> builtins.int:
        """
        ALB实例计费类型，当前仅支持按量计费（取值为1）。
        """
        return pulumi.get(self, "load_balancer_billing_type")

    @property
    @pulumi.getter(name="loadBalancerEdition")
    def load_balancer_edition(self) -> builtins.str:
        """
        应用型负载均衡的版本。Basic：基础版；Standard：标准版。
        """
        return pulumi.get(self, "load_balancer_edition")

    @property
    @pulumi.getter(name="loadBalancerId")
    def load_balancer_id(self) -> builtins.str:
        """
        ALB 实例 ID。
        """
        return pulumi.get(self, "load_balancer_id")

    @property
    @pulumi.getter(name="loadBalancerName")
    def load_balancer_name(self) -> builtins.str:
        """
        ALB 实例的名称。
        """
        return pulumi.get(self, "load_balancer_name")

    @property
    @pulumi.getter(name="lockReason")
    def lock_reason(self) -> builtins.str:
        """
        ALB 实例被冻结的原因，例如 Financial（欠费）或 Security（安全原因）。仅在实例被锁定时返回。
        """
        return pulumi.get(self, "lock_reason")

    @property
    @pulumi.getter(name="modificationProtectionReason")
    def modification_protection_reason(self) -> builtins.str:
        """
        修改保护原因。仅在 ModificationProtectionStatus 为 ConsoleProtection 时，该参数有效且合法。
        """
        return pulumi.get(self, "modification_protection_reason")

    @property
    @pulumi.getter(name="modificationProtectionStatus")
    def modification_protection_status(self) -> builtins.str:
        """
        修改保护状态。NonProtection：不保护；ConsoleProtection：控制台修改保护，通过控制台无法修改实例配置。
        """
        return pulumi.get(self, "modification_protection_status")

    @property
    @pulumi.getter(name="overdueTime")
    def overdue_time(self) -> builtins.str:
        """
        ALB 实例的冻结时间。该参数只有实例处于 FinancialLocked 状态时有返回值。
        """
        return pulumi.get(self, "overdue_time")

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> builtins.str:
        """
        实例所属项目名称。
        """
        return pulumi.get(self, "project_name")

    @property
    @pulumi.getter
    def status(self) -> builtins.str:
        """
        ALB 实例状态：Active（运行中）、Provisioning（创建中）、Configuring（配置中）、Deleting（删除中）、CreateFailed（创建失败）、Inactive（已停止）。
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def tags(self) -> Sequence['outputs.GetLoadBalancerTagResult']:
        """
        为实例绑定的标签列表，用于分类和计费。
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter
    def type(self) -> builtins.str:
        """
        ALB 实例的类型。取值是 public 或 private 。public：表示创建一个公网负载均衡实例，系统会分配一个公网IP地址和一个私网IP地址，可用于转发公网请求和私网请求。private：表示创建一个私网负载均衡实例，系统会分配一个私网IP地址，仅用于转发私网请求。
        """
        return pulumi.get(self, "type")

    @property
    @pulumi.getter(name="updateTime")
    def update_time(self) -> builtins.str:
        """
        ALB 实例的最后更新时间。
        """
        return pulumi.get(self, "update_time")

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> builtins.str:
        """
        负载均衡实例所属的私有网络（VPC）的ID。
        """
        return pulumi.get(self, "vpc_id")

    @property
    @pulumi.getter(name="wafInstanceId")
    def waf_instance_id(self) -> builtins.str:
        """
        ALB 实例绑定的 WAF 安全防护实例 ID。
        """
        return pulumi.get(self, "waf_instance_id")

    @property
    @pulumi.getter(name="wafProtectedDomain")
    def waf_protected_domain(self) -> builtins.str:
        """
        WAF防护的域名，用于精确匹配防护规则。
        """
        return pulumi.get(self, "waf_protected_domain")

    @property
    @pulumi.getter(name="wafProtectionEnabled")
    def waf_protection_enabled(self) -> builtins.str:
        """
        WAF 安全防护开关。on：开启；off：关闭。
        """
        return pulumi.get(self, "waf_protection_enabled")

    @property
    @pulumi.getter(name="zoneMappings")
    def zone_mappings(self) -> Sequence['outputs.GetLoadBalancerZoneMappingResult']:
        """
        可用区映射列表，定义了实例在哪些可用区提供服务。
        """
        return pulumi.get(self, "zone_mappings")


class AwaitableGetLoadBalancerResult(GetLoadBalancerResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetLoadBalancerResult(
            address_ip_version=self.address_ip_version,
            bandwidth_package_id=self.bandwidth_package_id,
            business_status=self.business_status,
            create_time=self.create_time,
            delete_protection=self.delete_protection,
            deleted_time=self.deleted_time,
            description=self.description,
            dns_name=self.dns_name,
            eip_billing_config=self.eip_billing_config,
            global_accelerator=self.global_accelerator,
            id=self.id,
            ipv6_eip_billing_config=self.ipv6_eip_billing_config,
            load_balancer_billing_type=self.load_balancer_billing_type,
            load_balancer_edition=self.load_balancer_edition,
            load_balancer_id=self.load_balancer_id,
            load_balancer_name=self.load_balancer_name,
            lock_reason=self.lock_reason,
            modification_protection_reason=self.modification_protection_reason,
            modification_protection_status=self.modification_protection_status,
            overdue_time=self.overdue_time,
            project_name=self.project_name,
            status=self.status,
            tags=self.tags,
            type=self.type,
            update_time=self.update_time,
            vpc_id=self.vpc_id,
            waf_instance_id=self.waf_instance_id,
            waf_protected_domain=self.waf_protected_domain,
            waf_protection_enabled=self.waf_protection_enabled,
            zone_mappings=self.zone_mappings)


def get_load_balancer(id: Optional[builtins.str] = None,
                      opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetLoadBalancerResult:
    """
    Data Source schema for Byteplus::ALB::LoadBalancer


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('bytepluscc:alb/getLoadBalancer:getLoadBalancer', __args__, opts=opts, typ=GetLoadBalancerResult).value

    return AwaitableGetLoadBalancerResult(
        address_ip_version=pulumi.get(__ret__, 'address_ip_version'),
        bandwidth_package_id=pulumi.get(__ret__, 'bandwidth_package_id'),
        business_status=pulumi.get(__ret__, 'business_status'),
        create_time=pulumi.get(__ret__, 'create_time'),
        delete_protection=pulumi.get(__ret__, 'delete_protection'),
        deleted_time=pulumi.get(__ret__, 'deleted_time'),
        description=pulumi.get(__ret__, 'description'),
        dns_name=pulumi.get(__ret__, 'dns_name'),
        eip_billing_config=pulumi.get(__ret__, 'eip_billing_config'),
        global_accelerator=pulumi.get(__ret__, 'global_accelerator'),
        id=pulumi.get(__ret__, 'id'),
        ipv6_eip_billing_config=pulumi.get(__ret__, 'ipv6_eip_billing_config'),
        load_balancer_billing_type=pulumi.get(__ret__, 'load_balancer_billing_type'),
        load_balancer_edition=pulumi.get(__ret__, 'load_balancer_edition'),
        load_balancer_id=pulumi.get(__ret__, 'load_balancer_id'),
        load_balancer_name=pulumi.get(__ret__, 'load_balancer_name'),
        lock_reason=pulumi.get(__ret__, 'lock_reason'),
        modification_protection_reason=pulumi.get(__ret__, 'modification_protection_reason'),
        modification_protection_status=pulumi.get(__ret__, 'modification_protection_status'),
        overdue_time=pulumi.get(__ret__, 'overdue_time'),
        project_name=pulumi.get(__ret__, 'project_name'),
        status=pulumi.get(__ret__, 'status'),
        tags=pulumi.get(__ret__, 'tags'),
        type=pulumi.get(__ret__, 'type'),
        update_time=pulumi.get(__ret__, 'update_time'),
        vpc_id=pulumi.get(__ret__, 'vpc_id'),
        waf_instance_id=pulumi.get(__ret__, 'waf_instance_id'),
        waf_protected_domain=pulumi.get(__ret__, 'waf_protected_domain'),
        waf_protection_enabled=pulumi.get(__ret__, 'waf_protection_enabled'),
        zone_mappings=pulumi.get(__ret__, 'zone_mappings'))
def get_load_balancer_output(id: Optional[pulumi.Input[builtins.str]] = None,
                             opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetLoadBalancerResult]:
    """
    Data Source schema for Byteplus::ALB::LoadBalancer


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('bytepluscc:alb/getLoadBalancer:getLoadBalancer', __args__, opts=opts, typ=GetLoadBalancerResult)
    return __ret__.apply(lambda __response__: GetLoadBalancerResult(
        address_ip_version=pulumi.get(__response__, 'address_ip_version'),
        bandwidth_package_id=pulumi.get(__response__, 'bandwidth_package_id'),
        business_status=pulumi.get(__response__, 'business_status'),
        create_time=pulumi.get(__response__, 'create_time'),
        delete_protection=pulumi.get(__response__, 'delete_protection'),
        deleted_time=pulumi.get(__response__, 'deleted_time'),
        description=pulumi.get(__response__, 'description'),
        dns_name=pulumi.get(__response__, 'dns_name'),
        eip_billing_config=pulumi.get(__response__, 'eip_billing_config'),
        global_accelerator=pulumi.get(__response__, 'global_accelerator'),
        id=pulumi.get(__response__, 'id'),
        ipv6_eip_billing_config=pulumi.get(__response__, 'ipv6_eip_billing_config'),
        load_balancer_billing_type=pulumi.get(__response__, 'load_balancer_billing_type'),
        load_balancer_edition=pulumi.get(__response__, 'load_balancer_edition'),
        load_balancer_id=pulumi.get(__response__, 'load_balancer_id'),
        load_balancer_name=pulumi.get(__response__, 'load_balancer_name'),
        lock_reason=pulumi.get(__response__, 'lock_reason'),
        modification_protection_reason=pulumi.get(__response__, 'modification_protection_reason'),
        modification_protection_status=pulumi.get(__response__, 'modification_protection_status'),
        overdue_time=pulumi.get(__response__, 'overdue_time'),
        project_name=pulumi.get(__response__, 'project_name'),
        status=pulumi.get(__response__, 'status'),
        tags=pulumi.get(__response__, 'tags'),
        type=pulumi.get(__response__, 'type'),
        update_time=pulumi.get(__response__, 'update_time'),
        vpc_id=pulumi.get(__response__, 'vpc_id'),
        waf_instance_id=pulumi.get(__response__, 'waf_instance_id'),
        waf_protected_domain=pulumi.get(__response__, 'waf_protected_domain'),
        waf_protection_enabled=pulumi.get(__response__, 'waf_protection_enabled'),
        zone_mappings=pulumi.get(__response__, 'zone_mappings')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetNlbListenerResult',
    'AwaitableGetNlbListenerResult',
    'get_nlb_listener',
    'get_nlb_listener_output',
]

@pulumi.output_type
class GetNlbListenerResult:
    """
    A collection of values returned by getNlbListener.
    """
    def __init__(__self__, certificate_id=None, connection_timeout=None, created_time=None, description=None, enabled=None, end_port=None, healths=None, id=None, listener_id=None, listener_name=None, load_balancer_id=None, port=None, protocol=None, security_policy_id=None, server_group_id=None, start_port=None, status=None, tags=None, updated_time=None):
        if certificate_id and not isinstance(certificate_id, str):
            raise TypeError("Expected argument 'certificate_id' to be a str")
        pulumi.set(__self__, "certificate_id", certificate_id)
        if connection_timeout and not isinstance(connection_timeout, int):
            raise TypeError("Expected argument 'connection_timeout' to be a int")
        pulumi.set(__self__, "connection_timeout", connection_timeout)
        if created_time and not isinstance(created_time, str):
            raise TypeError("Expected argument 'created_time' to be a str")
        pulumi.set(__self__, "created_time", created_time)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if enabled and not isinstance(enabled, bool):
            raise TypeError("Expected argument 'enabled' to be a bool")
        pulumi.set(__self__, "enabled", enabled)
        if end_port and not isinstance(end_port, int):
            raise TypeError("Expected argument 'end_port' to be a int")
        pulumi.set(__self__, "end_port", end_port)
        if healths and not isinstance(healths, list):
            raise TypeError("Expected argument 'healths' to be a list")
        pulumi.set(__self__, "healths", healths)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if listener_id and not isinstance(listener_id, str):
            raise TypeError("Expected argument 'listener_id' to be a str")
        pulumi.set(__self__, "listener_id", listener_id)
        if listener_name and not isinstance(listener_name, str):
            raise TypeError("Expected argument 'listener_name' to be a str")
        pulumi.set(__self__, "listener_name", listener_name)
        if load_balancer_id and not isinstance(load_balancer_id, str):
            raise TypeError("Expected argument 'load_balancer_id' to be a str")
        pulumi.set(__self__, "load_balancer_id", load_balancer_id)
        if port and not isinstance(port, int):
            raise TypeError("Expected argument 'port' to be a int")
        pulumi.set(__self__, "port", port)
        if protocol and not isinstance(protocol, str):
            raise TypeError("Expected argument 'protocol' to be a str")
        pulumi.set(__self__, "protocol", protocol)
        if security_policy_id and not isinstance(security_policy_id, str):
            raise TypeError("Expected argument 'security_policy_id' to be a str")
        pulumi.set(__self__, "security_policy_id", security_policy_id)
        if server_group_id and not isinstance(server_group_id, str):
            raise TypeError("Expected argument 'server_group_id' to be a str")
        pulumi.set(__self__, "server_group_id", server_group_id)
        if start_port and not isinstance(start_port, int):
            raise TypeError("Expected argument 'start_port' to be a int")
        pulumi.set(__self__, "start_port", start_port)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if tags and not isinstance(tags, list):
            raise TypeError("Expected argument 'tags' to be a list")
        pulumi.set(__self__, "tags", tags)
        if updated_time and not isinstance(updated_time, str):
            raise TypeError("Expected argument 'updated_time' to be a str")
        pulumi.set(__self__, "updated_time", updated_time)

    @property
    @pulumi.getter(name="certificateId")
    def certificate_id(self) -> builtins.str:
        """
        TLS监听器服务器证书的ID，仅支持传入证书中心 SSL 证书。。
        """
        return pulumi.get(self, "certificate_id")

    @property
    @pulumi.getter(name="connectionTimeout")
    def connection_timeout(self) -> builtins.int:
        """
        监听器的连接超时时间（秒）。
        """
        return pulumi.get(self, "connection_timeout")

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> builtins.str:
        """
        监听器的创建时间。
        """
        return pulumi.get(self, "created_time")

    @property
    @pulumi.getter
    def description(self) -> builtins.str:
        """
        监听器描述信息。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def enabled(self) -> builtins.bool:
        """
        是否启用监听器。true：开启；false：关闭。
        """
        return pulumi.get(self, "enabled")

    @property
    @pulumi.getter(name="endPort")
    def end_port(self) -> builtins.int:
        """
        全端口监听的结束端口，仅当Port为0时有效。
        """
        return pulumi.get(self, "end_port")

    @property
    @pulumi.getter
    def healths(self) -> Sequence['outputs.GetNlbListenerHealthResult']:
        """
        后端实例健康检查响应信息。
        """
        return pulumi.get(self, "healths")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        Uniquely identifies the resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="listenerId")
    def listener_id(self) -> builtins.str:
        """
        监听器唯一标识。
        """
        return pulumi.get(self, "listener_id")

    @property
    @pulumi.getter(name="listenerName")
    def listener_name(self) -> builtins.str:
        """
        监听器名称。
        """
        return pulumi.get(self, "listener_name")

    @property
    @pulumi.getter(name="loadBalancerId")
    def load_balancer_id(self) -> builtins.str:
        """
        负载均衡实例ID。
        """
        return pulumi.get(self, "load_balancer_id")

    @property
    @pulumi.getter
    def port(self) -> builtins.int:
        """
        监听器接收请求的端口，0表示启用全端口监听。
        """
        return pulumi.get(self, "port")

    @property
    @pulumi.getter
    def protocol(self) -> builtins.str:
        """
        监听协议类型。TCP,UDP,TLS
        """
        return pulumi.get(self, "protocol")

    @property
    @pulumi.getter(name="securityPolicyId")
    def security_policy_id(self) -> builtins.str:
        """
        TLS 安全策略ID，支持系统安全策略和自定义安全策略。系统安全策略取值：.tls*cipher*policy*1*0.tls*cipher*policy*1*1.tls*cipher*policy*1*2.tls*cipher*policy*1*2*strict.tls*cipher*policy*1*2*strict*with*1_3.自定义安全策略：输入自定义安全策略 ID。当Protocol为TLS 时，该参数为必填。。
        """
        return pulumi.get(self, "security_policy_id")

    @property
    @pulumi.getter(name="serverGroupId")
    def server_group_id(self) -> builtins.str:
        """
        监听器关联的服务器组ID。
        """
        return pulumi.get(self, "server_group_id")

    @property
    @pulumi.getter(name="startPort")
    def start_port(self) -> builtins.int:
        """
        全端口监听的起始端口，仅当Port为0时有效。
        """
        return pulumi.get(self, "start_port")

    @property
    @pulumi.getter
    def status(self) -> builtins.str:
        """
        监听器的状态。
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def tags(self) -> Sequence['outputs.GetNlbListenerTagResult']:
        """
        资源标签。
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="updatedTime")
    def updated_time(self) -> builtins.str:
        """
        监听器最近操作时间。
        """
        return pulumi.get(self, "updated_time")


class AwaitableGetNlbListenerResult(GetNlbListenerResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetNlbListenerResult(
            certificate_id=self.certificate_id,
            connection_timeout=self.connection_timeout,
            created_time=self.created_time,
            description=self.description,
            enabled=self.enabled,
            end_port=self.end_port,
            healths=self.healths,
            id=self.id,
            listener_id=self.listener_id,
            listener_name=self.listener_name,
            load_balancer_id=self.load_balancer_id,
            port=self.port,
            protocol=self.protocol,
            security_policy_id=self.security_policy_id,
            server_group_id=self.server_group_id,
            start_port=self.start_port,
            status=self.status,
            tags=self.tags,
            updated_time=self.updated_time)


def get_nlb_listener(id: Optional[builtins.str] = None,
                     opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetNlbListenerResult:
    """
    Data Source schema for Byteplus::CLB::NLBListener


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('bytepluscc:clb/getNlbListener:getNlbListener', __args__, opts=opts, typ=GetNlbListenerResult).value

    return AwaitableGetNlbListenerResult(
        certificate_id=pulumi.get(__ret__, 'certificate_id'),
        connection_timeout=pulumi.get(__ret__, 'connection_timeout'),
        created_time=pulumi.get(__ret__, 'created_time'),
        description=pulumi.get(__ret__, 'description'),
        enabled=pulumi.get(__ret__, 'enabled'),
        end_port=pulumi.get(__ret__, 'end_port'),
        healths=pulumi.get(__ret__, 'healths'),
        id=pulumi.get(__ret__, 'id'),
        listener_id=pulumi.get(__ret__, 'listener_id'),
        listener_name=pulumi.get(__ret__, 'listener_name'),
        load_balancer_id=pulumi.get(__ret__, 'load_balancer_id'),
        port=pulumi.get(__ret__, 'port'),
        protocol=pulumi.get(__ret__, 'protocol'),
        security_policy_id=pulumi.get(__ret__, 'security_policy_id'),
        server_group_id=pulumi.get(__ret__, 'server_group_id'),
        start_port=pulumi.get(__ret__, 'start_port'),
        status=pulumi.get(__ret__, 'status'),
        tags=pulumi.get(__ret__, 'tags'),
        updated_time=pulumi.get(__ret__, 'updated_time'))
def get_nlb_listener_output(id: Optional[pulumi.Input[builtins.str]] = None,
                            opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetNlbListenerResult]:
    """
    Data Source schema for Byteplus::CLB::NLBListener


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('bytepluscc:clb/getNlbListener:getNlbListener', __args__, opts=opts, typ=GetNlbListenerResult)
    return __ret__.apply(lambda __response__: GetNlbListenerResult(
        certificate_id=pulumi.get(__response__, 'certificate_id'),
        connection_timeout=pulumi.get(__response__, 'connection_timeout'),
        created_time=pulumi.get(__response__, 'created_time'),
        description=pulumi.get(__response__, 'description'),
        enabled=pulumi.get(__response__, 'enabled'),
        end_port=pulumi.get(__response__, 'end_port'),
        healths=pulumi.get(__response__, 'healths'),
        id=pulumi.get(__response__, 'id'),
        listener_id=pulumi.get(__response__, 'listener_id'),
        listener_name=pulumi.get(__response__, 'listener_name'),
        load_balancer_id=pulumi.get(__response__, 'load_balancer_id'),
        port=pulumi.get(__response__, 'port'),
        protocol=pulumi.get(__response__, 'protocol'),
        security_policy_id=pulumi.get(__response__, 'security_policy_id'),
        server_group_id=pulumi.get(__response__, 'server_group_id'),
        start_port=pulumi.get(__response__, 'start_port'),
        status=pulumi.get(__response__, 'status'),
        tags=pulumi.get(__response__, 'tags'),
        updated_time=pulumi.get(__response__, 'updated_time')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetKeypairResult',
    'AwaitableGetKeypairResult',
    'get_keypair',
    'get_keypair_output',
]

@pulumi.output_type
class GetKeypairResult:
    """
    A collection of values returned by getKeypair.
    """
    def __init__(__self__, created_time=None, description=None, finger_print=None, id=None, instance_ids=None, key_pair_id=None, key_pair_name=None, project_name=None, public_key=None, tags=None, updated_time=None):
        if created_time and not isinstance(created_time, str):
            raise TypeError("Expected argument 'created_time' to be a str")
        pulumi.set(__self__, "created_time", created_time)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if finger_print and not isinstance(finger_print, str):
            raise TypeError("Expected argument 'finger_print' to be a str")
        pulumi.set(__self__, "finger_print", finger_print)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if instance_ids and not isinstance(instance_ids, list):
            raise TypeError("Expected argument 'instance_ids' to be a list")
        pulumi.set(__self__, "instance_ids", instance_ids)
        if key_pair_id and not isinstance(key_pair_id, str):
            raise TypeError("Expected argument 'key_pair_id' to be a str")
        pulumi.set(__self__, "key_pair_id", key_pair_id)
        if key_pair_name and not isinstance(key_pair_name, str):
            raise TypeError("Expected argument 'key_pair_name' to be a str")
        pulumi.set(__self__, "key_pair_name", key_pair_name)
        if project_name and not isinstance(project_name, str):
            raise TypeError("Expected argument 'project_name' to be a str")
        pulumi.set(__self__, "project_name", project_name)
        if public_key and not isinstance(public_key, str):
            raise TypeError("Expected argument 'public_key' to be a str")
        pulumi.set(__self__, "public_key", public_key)
        if tags and not isinstance(tags, list):
            raise TypeError("Expected argument 'tags' to be a list")
        pulumi.set(__self__, "tags", tags)
        if updated_time and not isinstance(updated_time, str):
            raise TypeError("Expected argument 'updated_time' to be a str")
        pulumi.set(__self__, "updated_time", updated_time)

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> builtins.str:
        """
        密钥对创建时间。
        """
        return pulumi.get(self, "created_time")

    @property
    @pulumi.getter
    def description(self) -> builtins.str:
        """
        密钥对的描述，默认值为空字符串。必须以字母或中文开头。只能包含中文、字母、数字、点“.”、空格、下划线“_”、中划线“-”、等号“=”、英文逗号“,”、中文逗号“，”和中文句号“。”长度限制在255个字符以内。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="fingerPrint")
    def finger_print(self) -> builtins.str:
        """
        密钥对的指纹。根据RFC4716定义的公钥指纹格式，采用MD5信息摘要算法。
        """
        return pulumi.get(self, "finger_print")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        Uniquely identifies the resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="instanceIds")
    def instance_ids(self) -> Sequence[builtins.str]:
        """
        操作的实例ID。
        """
        return pulumi.get(self, "instance_ids")

    @property
    @pulumi.getter(name="keyPairId")
    def key_pair_id(self) -> builtins.str:
        """
        密钥对唯一ID。
        """
        return pulumi.get(self, "key_pair_id")

    @property
    @pulumi.getter(name="keyPairName")
    def key_pair_name(self) -> builtins.str:
        """
        密钥对名称。不可与已有名称重复。长度限制在 2～64 个字符之间。允许使用点号“.”分隔字符成多段，每段允许使用大小写字母、数字或连字符“-”。不能以“-”和“.”开头或结尾，不能连续使用“-”或者“.”。
        """
        return pulumi.get(self, "key_pair_name")

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> builtins.str:
        """
        资源所属项目，一个资源只能归属于一个项目。只能包含字母、数字、下划线“_”、点“.”和中划线“-”。长度限制在64个字符以内。
        """
        return pulumi.get(self, "project_name")

    @property
    @pulumi.getter(name="publicKey")
    def public_key(self) -> builtins.str:
        """
        密钥对的公钥信息。
        """
        return pulumi.get(self, "public_key")

    @property
    @pulumi.getter
    def tags(self) -> Sequence['outputs.GetKeypairTagResult']:
        """
        密钥对的标签。
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="updatedTime")
    def updated_time(self) -> builtins.str:
        """
        密钥对更新时间。
        """
        return pulumi.get(self, "updated_time")


class AwaitableGetKeypairResult(GetKeypairResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetKeypairResult(
            created_time=self.created_time,
            description=self.description,
            finger_print=self.finger_print,
            id=self.id,
            instance_ids=self.instance_ids,
            key_pair_id=self.key_pair_id,
            key_pair_name=self.key_pair_name,
            project_name=self.project_name,
            public_key=self.public_key,
            tags=self.tags,
            updated_time=self.updated_time)


def get_keypair(id: Optional[builtins.str] = None,
                opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetKeypairResult:
    """
    Data Source schema for Byteplus::ECS::Keypair


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('bytepluscc:ecs/getKeypair:getKeypair', __args__, opts=opts, typ=GetKeypairResult).value

    return AwaitableGetKeypairResult(
        created_time=pulumi.get(__ret__, 'created_time'),
        description=pulumi.get(__ret__, 'description'),
        finger_print=pulumi.get(__ret__, 'finger_print'),
        id=pulumi.get(__ret__, 'id'),
        instance_ids=pulumi.get(__ret__, 'instance_ids'),
        key_pair_id=pulumi.get(__ret__, 'key_pair_id'),
        key_pair_name=pulumi.get(__ret__, 'key_pair_name'),
        project_name=pulumi.get(__ret__, 'project_name'),
        public_key=pulumi.get(__ret__, 'public_key'),
        tags=pulumi.get(__ret__, 'tags'),
        updated_time=pulumi.get(__ret__, 'updated_time'))
def get_keypair_output(id: Optional[pulumi.Input[builtins.str]] = None,
                       opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetKeypairResult]:
    """
    Data Source schema for Byteplus::ECS::Keypair


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('bytepluscc:ecs/getKeypair:getKeypair', __args__, opts=opts, typ=GetKeypairResult)
    return __ret__.apply(lambda __response__: GetKeypairResult(
        created_time=pulumi.get(__response__, 'created_time'),
        description=pulumi.get(__response__, 'description'),
        finger_print=pulumi.get(__response__, 'finger_print'),
        id=pulumi.get(__response__, 'id'),
        instance_ids=pulumi.get(__response__, 'instance_ids'),
        key_pair_id=pulumi.get(__response__, 'key_pair_id'),
        key_pair_name=pulumi.get(__response__, 'key_pair_name'),
        project_name=pulumi.get(__response__, 'project_name'),
        public_key=pulumi.get(__response__, 'public_key'),
        tags=pulumi.get(__response__, 'tags'),
        updated_time=pulumi.get(__response__, 'updated_time')))
